%define kernel_git_commit cc050d71c9381bf03232725eb6c53c03633694dc
%define kernel_git_commit 74c661676446c010ea6f46dab7231d98761d66a5
%global __spec_install_pre %{___build_pre}

# Errors in specfile are causing builds to fail. Adding workarounds.
%define _unpackaged_files_terminate_build       0
%define _missing_doc_files_terminate_build      0

Summary: The Linux kernel

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%define released_kernel 1
# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# % define buildid .local

%define distro_build 100
%define signmodules 1

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%define base_sublevel 13

## If this is a released kernel ##
%if 0%{?released_kernel}

# Do we have a -stable update to apply?
%define stable_update 0
# Is it a -stable RC?
%define stable_rc 0
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%define stable_base %{stable_update}
%if 0%{?stable_rc}
# stable RCs are incremental patches, so we need the previous stable patch
%define stable_base %(echo $((%{stable_update} - 1)))
%endif
%endif
%define rpmversion 3.8.%{base_sublevel}%{?stablerev}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(echo $((%{base_sublevel} + 1)))
# The rc snapshot level
%define rcrev 0
# The git snapshot level
%define gitrev 0
# Set rpm version accordingly
%define rpmversion 3.8.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        1
# kernel-smp (only valid for ppc 32-bit, sparc64)
%define with_smp       1
# kernel-kdump
%define with_kdump     0
# kernel-debug
%define with_debug     1
# kernel-doc
%define with_doc       1
# kernel-headers
%define with_headers   1
# dtrace
%define with_dtrace    0
# kernel-firmware
%define with_firmware  0
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{?!_without_bootwrapper: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%if 0%{?released_kernel}
%define doc_build_fail false
%else
%define doc_build_fail true
%endif

# Control whether we perform a compat. check against published ABI.
%ifarch sparc64
%define with_kabichk 0
%define fancy_debuginfo 0
%else
%define with_kabichk 1 
%define fancy_debuginfo 1
%endif

# Control whether we build the hmac for fips mode.
%define with_fips      %{?_without_fips:      0} %{?!_without_fips:      1}

%if %{fancy_debuginfo}
BuildRequires: rpm-build >= 4.4.2.1-4
%define debuginfo_args --strict-build-id
%endif

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the smp kernel (--with smponly):
%define with_smponly   %{?_with_smponly:      1} %{?!_with_smponly:      0}

# should we do C=1 builds with sparse
%define with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
%define debugbuildsenabled 1

# Want to build a vanilla kernel build without any non-upstream patches?
# (well, almost none, we need nonintconfig for build purposes). Default to 0 (off).
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}

%if 0%{?stable_rc}
%define stable_rctag .rc%{stable_rc}
%endif
%define pkg_release 16.2.3%{?dist}uek%{?buildid}

%else

# non-released_kernel
%if 0%{?rcrev}
%define rctag .rc%rcrev
%else
%define rctag .rc0
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%else
%define gittag .git0
%endif
%define pkg_release 16.2.3%{?dist}uek%{?buildid}

%endif

# The kernel tarball/base version
%define kversion 3.8.13

%define make_target bzImage

%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%define with_bootwrapper 0

%define pkg_release 16.2.3%{?dist}uek%{?buildid}

%define KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

%define with_pae 0

# if requested, only build base kernel
%if %{with_baseonly}
%define with_smp 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_kdump 0
%define with_debug 0
%endif

%define all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64
%endif

# Overrides for generic default options

# only ppc need separate smp kernels
%ifnarch ppc alphaev56
%define with_smp 0
%endif

# only build kernel-kdump on ppc64
# (no relocatable kernel support upstream yet)
#FIXME: Temporarily disabled to speed up builds.
#ifnarch ppc64
%define with_kdump 0
#endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%endif

# no need to build headers again for these arches,
# they can just use i586 and ppc64 headers
%ifarch ppc64iseries
%define with_headers 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_paravirt 0
%define with_paravirt_debug 0
%define all_arch_configs kernel-%{version}-*.config
%define with_firmware  %{?_without_firmware:  0} %{?!_without_firmware:  1}
%endif

# bootwrapper is only on ppc
%ifnarch ppc ppc64
%define with_bootwrapper 0
%endif

# sparse blows up on ppc64 alpha and sparc64
%ifarch ppc64 ppc alpha sparc64
%define with_sparse 0
%endif

# Only x86_64 does dtrace
%ifarch x86_64
%define with_dtrace 1
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
#%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch sparc
# We only build sparc headers since we dont support sparc32 hardware
%endif

%ifarch sparc64
%define asmarch sparc
%define all_arch_configs kernel-%{version}-sparc64*.config
%define make_target image
%define kernel_image arch/sparc/boot/image
%define image_install_path boot
%endif

%ifarch ppc
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch ia64
%define all_arch_configs kernel-%{version}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define make_target compressed
%define kernel_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%define all_arch_configs kernel-%{version}-alpha*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define image_install_path boot
%define hdrarch arm
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%if %{nopatches}
# XXX temporary until last vdso patches are upstream
%define vdso_arches ppc ppc64
%endif

%define oldconfig_target oldnoconfig

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
##%define nobuildarches i386 s390 sparc %{arm}
%define nobuildarches s390 sparc %{arm}

%ifarch %nobuildarches
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debuginfo 0
%define _enable_debug_packages 0
%define with_paravirt 0
%define with_paravirt_debug 0
%endif

%define with_pae_debug 0
%if %{with_pae}
%define with_pae_debug %{with_debug}
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
##%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14, device-mapper-multipath < 0.4.9-64

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define kernel_xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
%define kernel_smp_obsoletes kernel-enterprise < 2.4.10
%define kernel_PAE_obsoletes kernel-smp < 2.6.17, kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_PAE_provides kernel-xen = %{rpmversion}-%{pkg_release}

%ifarch x86_64
%define kernel_obsoletes kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_provides kernel%{?variant}-xen = %{rpmversion}-%{pkg_release}
%endif

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-firmware = %{rpmversion}-%{pkg_release}, /sbin/new-kernel-pkg, ql23xx-firmware
%define initrd_prereq  dracut-kernel >= 004-242.0.3

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel%{?variant} = %{rpmversion}-%{pkg_release}\
Provides: kernel%{?variant}-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel%{?variant}-drm = 4.3.0\
Provides: kernel%{?variant}-drm-nouveau = 12\
Provides: kernel%{?variant}-modeset = 1\
Provides: kernel%{?variant}-uname-r = %{KVERREL}%{?1:.%{1}}\
Provides: oracleasm = 2.0.5\
%ifnarch sparc64\
Provides: x86_energy_perf_policy = %{KVERREL}%{?1:.%{1}}\
%endif\
Provides: perf = %{KVERREL}%{?1:.%{1}}\
#Provides: libperf.a = %{KVERREL}%{?1:.%{1}}\
%ifarch sparc64\
Provides: kernel = %{rpmversion}-%{pkg_release}\
%endif\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(post): /sbin/new-kernel-pkg\
Requires(preun): /sbin/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

%define variant %{?build_variant:%{build_variant}}%{!?build_variant:-uek}
Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64 paravirt paravirt-debug ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56 %{arm}
ExclusiveOS: Linux

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif


#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12
BuildRequires: net-tools
BuildRequires: elfutils-libelf-devel
BuildRequires: python
BuildRequires: flex >= 2.5.19, bison >= 2.3
BuildRequires: pkgconfig
BuildRequires: glib2-devel
BuildRequires: elfutils-devel
%if %{with_doc}
BuildRequires: xmlto
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{signmodules}
BuildRequires: openssl
#BuildRequires: pesign >= 0.10-4
%endif
%if %{with_fips}
BuildRequires: hmaccalc
%endif
%if %{with_dtrace}
BuildRequires: libdtrace-ctf-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

%if %{signmodules}
Source10: x509.genkey
%endif

Source13: mod-sign.sh
%define modsign_cmd %{SOURCE13}

Source14: find-provides
Source16: perf
Source17: kabitool
Source18: check-kabi
Source19: extrakeys.pub
Source20: x86_energy_perf_policy

Source1000: config-x86_64
Source1001: config-x86_64-debug
Source1004: config-sparc
Source1005: config-sparc-debug

Source26: Module.kabi_x86_64

Source201: kabi_whitelist_x86_64

Source300: debuginfo-g1.diff

# Here should be only the patches up to the upstream canonical Linus tree.

# For a stable release kernel
%if 0%{?stable_update}
%if 0%{?stable_base}
%define    stable_patch_00  patch-2.6.%{base_sublevel}.%{stable_base}.bz2
Patch00: %{stable_patch_00}
%endif
%if 0%{?stable_rc}
%define    stable_patch_01  patch-2.6.%{base_sublevel}.%{stable_update}-rc%{stable_rc}.bz2
Patch01: %{stable_patch_01}
%endif

# non-released_kernel case
# These are automagically defined by the rcrev and gitrev values set up
# near the top of this spec file.
%else
%if 0%{?rcrev}
Patch00: patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
Patch01: patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
Patch00: patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif
%endif

%if !%{nopatches}
# revert patches place holder
%endif


BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
%global _use_internal_dependency_generator 0
%define __find_provides %_sourcedir/find-provides %{_tmppath}
%define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
Obsoletes: kernel-doc
Provides: kernel-doc
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Obsoletes: kernel-headers
Provides: kernel-headers
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
%if "x%{?variant}" != "x"
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
%endif
%ifarch sparc64
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
%endif
%description firmware
Kernel firmware includes firmware files required for some devices to
operate.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
Requires: gzip
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package debuginfo-common
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
%description debuginfo-common
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.


#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?variant}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?variant}-xen-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
%ifarch sparc64\
Provides: kernel-devel = %{version}-%{release}%{?1:.%{1}}\
%endif\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
Requires: elfutils-libelf\
Requires: elfutils-libs\
%if %{with_dtrace}\
Requires: libdtrace-ctf\
%endif\
%description -n kernel%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled for SMP machines
%kernel_variant_package -n SMP smp
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.


%define variant_summary The Linux kernel compiled for PAE capable machines
%kernel_variant_package PAE
%description PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.


%define variant_summary The Linux kernel compiled with extra debugging enabled for PAE capable machines
%kernel_variant_package PAEdebug
Obsoletes: kernel-PAE-debug
%description PAEdebug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.


%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}%{with_pae}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

%if %{with_smponly}
%if !%{with_smp}
echo "Cannot build --with smponly, smp build is disabled"
exit 1
%endif
%endif

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1;
  fi
  if ! egrep "^Patch[0-9]+: $patch\$" %{_specdir}/%{name}*.spec ; then
    [ "${patch:0:10}" != "patch-2.6." ] && echo "Patch $patch not listed in specfile" && exit 1;
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

test_config_file()
{
  TestConfig=$1
  Arch=`head -n 3 .config |grep -e "Linux.*Kernel" |cut -d '/' -f 2 | cut -d ' ' -f 1`
  if [ `make ARCH=$Arch listnewconfig 2>/dev/null | grep -c CONFIG`  -ne 0 ]; then 
	echo "Following config options are unconfigured"
	make ARCH=$Arch listnewconfig 2> /dev/null
	echo "WARNING: Kernel version and config file missmatch"
	echo "WARNING: This options will be unset by default in config file"
  fi
}

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.

# Update to latest upstream.
%if 0%{?released_kernel}
%define vanillaversion 2.6.%{base_sublevel}
# non-released_kernel case
%else
%if 0%{?rcrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}
%if 0%{?gitrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
%define vanillaversion 2.6.%{base_sublevel}-git%{gitrev}
%endif
%endif
%endif

# We can share hardlinked source trees by putting a list of
# directory names of the CVS checkouts that we want to share
# with in .shared-srctree. (Full pathnames are required.)
[ -f .shared-srctree ] && sharedirs=$(cat .shared-srctree)

if [ ! -d kernel-%{kversion}/vanilla-%{vanillaversion} ]; then

  if [ -d kernel-%{kversion}/vanilla-%{kversion} ]; then

    cd kernel-%{kversion}

    # Any vanilla-* directories other than the base one are stale.
    for dir in vanilla-*; do
      [ "$dir" = vanilla-%{kversion} ] || rm -rf $dir &
    done

  else

    # Ok, first time we do a make prep.
    rm -f pax_global_header
    for sharedir in $sharedirs ; do
      if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{kversion} ]] ; then
        break
      fi
    done
    if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{kversion} ]] ; then
%setup -q -n kernel-%{kversion} -c -T
      cp -rl $sharedir/kernel-%{kversion}/vanilla-%{kversion} .
    else
%setup -q -n kernel-%{kversion} -c
      mv linux-%{kversion} vanilla-%{kversion}
    fi

  fi

%if "%{kversion}" != "%{vanillaversion}"

  for sharedir in $sharedirs ; do
    if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} ]] ; then
      break
    fi
  done
  if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} ]] ; then

    cp -rl $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} .

  else

    cp -rl vanilla-%{kversion} vanilla-%{vanillaversion}
    cd vanilla-%{vanillaversion}

# Update vanilla to the latest upstream.
# (non-released_kernel case only)
%if 0%{?rcrev}
    ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
    ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
    ApplyPatch patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif

    cd ..

  fi

%endif

else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
fi

if [ -d linux-%{kversion}.%{_target_cpu} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

cp -rl vanilla-%{vanillaversion} linux-%{kversion}-%{release}
cd linux-%{kversion}-%{release}

# released_kernel with possible stable updates
%if 0%{?stable_base}
ApplyPatch %{stable_patch_00}
%endif
%if 0%{?stable_rc}
ApplyPatch %{stable_patch_01}
%endif

# Copy the RPM find-debuginfo.sh into the buildroot and patch it
# to support -g1.  (This is a patch of *RPM*, not of the kernel,
# so it is not governed by nopatches.)
cp %{_rpmconfigdir}/find-debuginfo.sh %{_builddir}
patch %{_builddir}/find-debuginfo.sh %{SOURCE300}
chmod +x %{_builddir}/find-debuginfo.sh

# only deal with configs if we are going to build for the arch
# %ifnarch %nobuildarches

mkdir -p configs 
%ifarch x86_64
	cp %{SOURCE1001} configs/config-debug 
	cp %{SOURCE1000} configs/config
%endif #ifarch x86_64

%ifarch i686
	cp %{SOURCE1003} configs/config-debug
	cp %{SOURCE1002} configs/config
%endif #ifarch i686

%ifarch sparc64
	cp %{SOURCE1005} configs/config-debug
	cp %{SOURCE1004} configs/config
%endif #ifarch sparc

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug \
    				-i $@ > $@.id"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile
    #perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{base_sublevel}/" Makefile

    make -s mrproper

    %if %{signmodules}
    	cp %{SOURCE10} .
   	chmod +x scripts/sign-file
    %endif

    if [ "$Flavour" == "debug" ]; then	
	cp configs/config-debug .config
    else
	cp configs/config .config
    fi

    Arch=`head -n 3 .config |grep -e "Linux.*Kernel" |cut -d '/' -f 2 | cut -d ' ' -f 1`
    echo USING ARCH=$Arch 
    make -s ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s ARCH=$Arch V=1 %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch V=1 %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    %if %{signmodules}
    	# Sign the image if we're using EFI
    	#% pesign -s -i $KernelImage -o vmlinuz.signed
	#    if [ -x /usr/bin/pesign -a "x86_64" == "x86_64" ]; then 
	#	    if [ -e /var/run/pesign/socket ]; then 
	#		    /usr/bin/pesign-client -t "OpenSC Card (Fedora Signer)" \
	#			    -c "/CN=Fedora Secure Boot Signer" \
	#		 	   -i $KernelImage -o vmlinuz.signed  -s  
	#	    else 
	#		    /usr/bin/pesign  -c "Oracle" \
	#			    -i $KernelImage -o vmlinuz.signed  -s  
	#			    fi 
	#    else 
	#	    if [ -n "$KernelImage" -a -n "vmlinuz.signed" ]; then 
	#		    mv $KernelImage vmlinuz.signed 
	#			    elif [ -n "$KernelImage" -a -n "" ]; then 
	#			    touch  
	#			    fi 
	#			    fi ;  
	#
    	#mv vmlinuz.signed $KernelImage
    %endif
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

%if %{with_fips}
    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
%endif

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    # Override $(mod-fw) because we don't want it to install any firmware
    # We'll do that ourselves with 'make firmware_install'
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    # check if the modules are being signed

%ifarch %{vdso_arches}
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if grep '^CONFIG_XEN=y$' .config >/dev/null; then
      echo > ldconfig-kernel.conf "\
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg"
    fi
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif
%ifarch %{vdso_arches} sparc64
%ifnarch noarch
# build tools/perf:
    if [ -d tools/perf ]; then
	cd tools/perf
	make all
# and install it:
#	mkdir -p $RPM_BUILD_ROOT/usr/bin/$KernelVer/
	mkdir -p $RPM_BUILD_ROOT/usr/libexec/
	install -m 755 perf $RPM_BUILD_ROOT/usr/libexec/perf.$KernelVer
	#install -m 755 libperf.a $RPM_BUILD_ROOT/lib/modules/$KernelVer/bin/%{_target_cpu}/libperf.a
	cd ../..
    fi
%endif
%ifarch x86_64 %{all_x86}
# build tools/power/x86/x86_energy_perf_policy:
    if [ -d tools/power/x86/x86_energy_perf_policy ]; then
       cd tools/power/x86/x86_energy_perf_policy
       make
# and install it:
       mkdir -p $RPM_BUILD_ROOT/usr/libexec/
       install -m 755 x86_energy_perf_policy $RPM_BUILD_ROOT/usr/libexec/x86_energy_perf_policy.$KernelVer
       cd ../../../../
    fi
%endif
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    chmod 0755 %_sourcedir/kabitool
    if [ -e $RPM_SOURCE_DIR/kabi_whitelist_%{_target_cpu}$Flavour ]; then
       cp $RPM_SOURCE_DIR/kabi_whitelist_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/kabi_whitelist
    fi
    rm -f %{_tmppath}/kernel-$KernelVer-kabideps
    %_sourcedir/kabitool -s Module.symvers -o %{_tmppath}/kernel-$KernelVer-kabideps 

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
       cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
       $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
       rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
       echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a --parents Kbuild $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents kernel/bounds.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/%{asmarch}/kernel/asm-offsets.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%ifnarch %{sparc}
    cp -a --parents arch/%{asmarch}/kernel/asm-offsets_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a --parents security/selinux/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/ 
    
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config generated crypto keys linux math-emu media uapi net pcmcia rdma rxrpc scsi sound trace video asm-generic drm xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    asmdir=../arch/%{asmarch}/include/asm
    cp -a $asmdir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/
    cd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include 
    ln -s $asmdir asm
    cd -
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

%if %{fancy_debuginfo}
    if test -s vmlinux.id; then
      cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id
    else
      echo >&2 "*** ERROR *** no vmlinux build ID! ***"
      exit 1
    fi
%endif

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
    }

    collect_modules_list networking \
     			 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|register_netdevice'
    collect_modules_list block \
     			 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size'
    collect_modules_list drm \
    			 'drm_open|drm_init'
    collect_modules_list modesetting \
    			 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

%if %{signmodules}
    # Save off the .tmp_versions/ directory.  We'll use it in the 
    # __debug_install_post macro below to sign the right things
    # Also save the signing keys so we actually sign the modules with the
    # right key.
    cp -r .tmp_versions .tmp_versions.sign${Flavour:+.${Flavour}}
    cp signing_key.priv signing_key.priv.sign${Flavour:+.${Flavour}}
    cp signing_key.x509 signing_key.x509.sign${Flavour:+.${Flavour}}
%endif

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias ccwmap dep ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{version}-%{release}

%if %{with_debug}
%if %{with_up}
BuildKernel %make_target %kernel_image debug
%endif
%if %{with_pae}
BuildKernel %make_target %kernel_image PAEdebug
%endif
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_smp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{with_kdump}
BuildKernel vmlinux vmlinux kdump vmlinux
%endif

%if %{with_doc}
# Make the HTML and man pages.
make -j1  htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%define __modsign_install_post \
  if [ "%{signmodules}" == "1" ]; then \
    if [ "%{with_pae}" != "0" ]; then \
      mv signing_key.priv.sign.PAE signing_key.priv \
      mv signing_key.x509.sign.PAE signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.PAE/ \
    fi \
    if [ "%{with_debug}" != "0" ]; then \
      mv signing_key.priv.sign.debug signing_key.priv \
      mv signing_key.x509.sign.debug signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.debug/ \
    fi \
    if [ "%{with_pae_debug}" != "0" ]; then \
      mv signing_key.priv.sign.PAEdebug signing_key.priv \
      mv signing_key.x509.sign.PAEdebug signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.PAEdebug/ \
    fi \
    if [ "%{with_up}" != "0" ]; then \
      mv signing_key.priv.sign signing_key.priv \
      mv signing_key.x509.sign signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
# TEMPORARY HACK: use the debuginfo in the build tree, passing it -g1 so as
# to strip out only debugging sections.
%define debug_package %{nil}
%if %{fancy_debuginfo}
%define __debug_install_post \
  %{_builddir}/find-debuginfo.sh %{debuginfo_args} -g1 %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{with_debuginfo}

%define __debug_install_post \
  %{_builddir}/find-debuginfo.sh %{debuginfo_args} -g1 %{_builddir}/%{?buildsubdir}\
%{nil}

%ifnarch noarch
%global __debug_package 1
%files debuginfo-common
%defattr(-,root,root)
%dir /usr/src/debug
/usr/src/debug/kernel-%{version}/linux-%{kversion}-%{release}
%dir %{debuginfodir}
%dir %{debuginfodir}/%{image_install_path}
%dir %{debuginfodir}/lib
%dir %{debuginfodir}/lib/modules
%dir %{debuginfodir}/usr/src/kernels
%endif
%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}

###
### install
###

%install
cd linux-%{version}-%{release}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif

%ifnarch noarch
# perf shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/perf $RPM_BUILD_ROOT/usr/sbin/perf
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf
%endif

%ifarch x86_64 %{all_x86}
# x86_energy_perf_policy shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/x86_energy_perf_policy $RPM_BUILD_ROOT/usr/sbin/x86_energy_perf_policy
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/x86_energy_perf_policy
%endif


%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h

# these are provided by drm-devel
rm -rf $RPM_BUILD_ROOT/usr/include/drm
%endif

%if %{with_firmware}
mkdir -p $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}
make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} firmware_install
%endif

%if %{with_bootwrapper}
make DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{kversion}-%{release}.%{_arch}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
(/sbin/grubby --info=`/sbin/grubby --default-kernel`) 2>/dev/null | grep -q "crashkernel=auto"\
if [ $? -eq 0 ];then\
  removeArgs="--remove-args=\"crashkernel=auto\""\
fi\
/sbin/new-kernel-pkg --package kernel%{?1:-%{1}} --mkinitrd --dracut --depmod ${removeArgs} --update %{KVERREL}%{?1:.%{1}} || exit $?\
/sbin/new-kernel-pkg --package kernel%{?1:-%{1}} --rpmposttrans %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --add-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(uv:r:) \
%{expand:%%kernel_devel_post %{!-u:%{?-v*}}}\
%{expand:%%kernel_variant_posttrans %{!-u:%{?-v*}}}\
%{expand:%%post %{!-u:%{?-v*}}}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
if grep --silent '^hwcap 0 nosegneg$' /etc/ld.so.conf.d/kernel-*.conf 2> /dev/null; then\
  sed -i '/^hwcap 0 nosegneg$/ s/0/1/' /etc/ld.so.conf.d/kernel-*.conf\
fi\
/sbin/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVERREL}%{!-u:%{?-v:.%{-v*}}} || exit $?\
ln -sf /lib/firmware/%{rpmversion}-%{pkg_release} /lib/firmware/%{rpmversion}-%{pkg_release}.%{_target_cpu} \
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --remove-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
   rm -f /lib/firmware/%{rpmversion}-%{pkg_release}.%{_target_cpu} \
fi\
%{nil}

#
# This macro defines a %%pre script for a kernel package.
#	%%kernel_variant_pre <subpackage>
#
%define kernel_variant_pre() \
%{expand:%%pre %{?1}}\
message="Change references of /dev/hd in /etc/fstab to disk label"\
if [ -f /etc/fstab ]\
then\
awk '($2=="/boot")&&/^\\/dev\\/hd/{print $1}' /etc/fstab | egrep -q "^/dev/hd"\
bdretval=$?\
awk '($2=="/")&&/^\\/dev\\/hd/{print $1}' /etc/fstab | egrep -q "^/dev/hd"\
rdretval=$?\
awk '($2=="/boot")&&/^LABEL=/{print $1}' /etc/fstab | egrep -q "^LABEL="\
blretval=$?\
awk '($2=="/")&&/^LABEL=/{print $1}' /etc/fstab | egrep -q "^LABEL="\
rlretval=$?\
if [ $bdretval == 0 ] || [ $rdretval == 0 ]\
then\
echo -e $message\
exit 1\
elif [ $blretval == 0 ] && [ $rlretval == 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $blretval == 0 ] && [ $rdretval != 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $bdretval != 0 ] && [ $rlretval == 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $bdretval != 0 ] && [ $rdretval != 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
fi\
fi\
%{nil}

%kernel_variant_pre
%kernel_variant_preun
%ifarch x86_64
%kernel_variant_post -u -v uek -r (kernel%{variant}|kernel%{variant}-debug|kernel-ovs)
%else
%kernel_variant_post -u -v uek -r (kernel%{variant}|kernel%{variant}-debug|kernel-ovs)
%endif

%kernel_variant_pre smp
%kernel_variant_preun smp
%kernel_variant_post -v smp

%kernel_variant_pre PAE
%kernel_variant_preun PAE
%kernel_variant_post -v PAE -r (kernel|kernel-smp|kernel-xen)

%kernel_variant_pre debug
%kernel_variant_preun debug
%kernel_variant_post -v debug

%kernel_variant_post -v PAEdebug -r (kernel|kernel-smp|kernel-xen)
%kernel_variant_preun PAEdebug
%kernel_variant_pre PAEdebug

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_firmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc linux-%{version}-%{release}/firmware/WHENCE
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
%if %{with_fips} \
/%{image_install_path}/.vmlinuz-%{KVERREL}%{?2:.%{2}}.hmac \
%endif \
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
/boot/symvers-%{KVERREL}%{?2:.%{2}}.gz\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVERREL}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.*\
/usr/libexec/perf.%{KVERREL}%{?2:.%{2}}\
/usr/sbin/perf\
%ifnarch sparc64\
/usr/libexec/x86_energy_perf_policy.%{KVERREL}%{?2:.%{2}}\
/usr/sbin/x86_energy_perf_policy\
%endif\
%ghost /boot/initramfs-%{KVERREL}%{?2:.%{2}}.img\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
%verify(not mtime) /usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%else\
%{expand:%%files %{?2:%{2}-}debuginfo}\
%endif\
%defattr(-,root,root)\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.%{2}}.debug\
%endif\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
# % {debuginfodir}/usr/bin/%{KVERREL}%{?2:.%{2}}\
%endif\
%endif\
%endif\
%endif\
%{nil}


%kernel_variant_files %{with_up}
%kernel_variant_files %{with_smp} smp
%if %{with_up}
%kernel_variant_files %{with_debug} debug
%endif
%kernel_variant_files %{with_pae} PAE
%kernel_variant_files %{with_pae_debug} PAEdebug
%kernel_variant_files -k vmlinux %{with_kdump} kdump

%changelog
* Fri Dec 13 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.2.3.el6uek] 
- ip_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [Orabug: 17951078] {CVE-2013-4470} 
- ip6_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [Orabug: 17951080] {CVE-2013-4470} 
- KVM: x86: fix guest-initiated crash with x2apic (CVE-2013-6376) (Gleb Natapov) [Orabug: 17951067] {CVE-2013-6376} 
- KVM: x86: Convert vapic synchronization to _cached functions (CVE-2013-6368) (Andy Honig) [Orabug: 17951071] {CVE-2013-6368} 
- KVM: x86: Fix potential divide by 0 in lapic (CVE-2013-6367) (Andy Honig) [Orabug: 17951073] {CVE-2013-6367} 

* Tue Nov 26 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.2.2.el6uek] 
- HID: pantherlord: validate output report details (Kees Cook) [Orabug: 17841973] {CVE-2013-2892} 
- HID: zeroplus: validate output report details (Kees Cook) [Orabug: 17841968] {CVE-2013-2889} 
- HID: provide a helper for validating hid reports (Kees Cook) [Orabug: 17841968] {CVE-2013-2889} 
- KVM: Fix iommu map/unmap to handle memory slot moves (Alex Williamson) [Orabug: 17841960] {CVE-2013-4592} 
- ansi_cprng: Fix off by one error in non-block size request (Jerry Snitselaar) [Orabug: 17837997] {CVE-2013-4345} 
- HID: validate HID report id size (Kees Cook) [Orabug: 17841940] {CVE-2013-2888} 
- ipv6: remove max_addresses check from ipv6_create_tempaddr (Hannes Frederic Sowa) [Orabug: 17841911] {CVE-2013-0343} 
- ipv6: udp packets following an UFO enqueued packet need also be handled by UFO (Hannes Frederic Sowa) [Orabug: 17841928] {CVE-2013-4387} 

* Thu Nov 7 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.2.1.el6uek] 
- xen-netfront: convert to GRO API (Wei Liu) [Orabug: 17759432]  
- xen-netfront: pull on receive skb may need to happen earlier (Jan Beulich) [Orabug: 17759399]  
- be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd (asundhara Volam) [Orabug: 17583192]  
- core/xen: Use _PAGE_IOMAP when mmaping PCI BARs. (Konrad Rzeszutek Wilk) [Orabug: 17753790]  
- dtrace: remove functionality of dtrace_os_exit() as deprecated (Kris Van Hees) [Orabug: 17717401]  
- dtrace: fix mutex_owned() implementation (Kris Van Hees) [Orabug: 17624236]  
- dtrace: new cyclic implementation (Kris Van Hees) [Orabug: 17553446]  
- dtrace: Use tasklet_hrtimer_*() instead of hrtimer_*() for cyclics (Kris Van Hees) [Orabug: 17553446]  
- dm mpath: disable WRITE SAME if it fails (Mike Snitzer) [Orabug: 17617256]  
- crypto: xor - Check for osxsave as well as avx in crypto/xor (John Haxby) [Orabug: 17066724]  
- bonding: If IP route look-up to send an ARP fails, mark in bonding structure as no ARP sent. (Rama Nichanamatlu) [Orabug: 17557056]  
- Audit: do not print error when LSMs disabled (Eric Paris) [Orabug: 17537769]  

* Tue Oct 22 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.1.1.el6uek] 
- dm snapshot: fix data corruption (Mikulas Patocka) [Orabug: 17617582] {CVE-2013-4299} 

* Thu Sep 19 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.el6uek] 
- oracleasm: Add support for new error return codes from block/SCSI (Martin K. Petersen) [Orabug: 17484923]  
- RDS: protocol negotiation fails during reconnect (Bang Nguyen) [Orabug: 17484877]  
- ocfs2/dlm: ocfs2 dlm umount skip migrating lockres (Srinivas Eeda) [Orabug: 16859627]  
- ocfs2/dlm: Fix list traversal in dlm_process_recovery_data (Srinivas Eeda) [Orabug: 17432400]  
- ocfs2: fix error handling in ocfs2_ioctl_move_extents() (Srinivas Eeda) [Orabug: 16631951]  
- ocfs2: btrfs: aio-dio-loop changes broke setrlimit behavior (Srinivas Eeda) [Orabug: 14207636]  
- ocfs2: xattr: fix inlined xattr reflink (Junxiao Bi) [Orabug: 15914937]  
- ocfs2: goto out_unlock if ocfs2_get_clusters_nocache() failed in ocfs2_fiemap() (Joseph Qi) [Orabug: 16963812]  
- ocfs2: Don't log error message when removing non-empty directory (Xiaowei.Hu) [Orabug: 16790405]  
- ocfs2: Suppress the error message from being printed in ocfs2_rename (Xiaowei.Hu) [Orabug: 16790405]  
- ocfs2: ocfs2_prep_new_orphaned_file return ret (Xiaowei.Hu) [Orabug: 16823825]  
- ocfs2: Fix NULL dereference for moving extents (Dan Carpenter) [Orabug: 16631951]  
- ocfs2: This is a fix on dlm_clean_master_list() (Xiaowei.Hu) [Orabug: 12798517]  
- ocfs2: submit disk heartbeat bio using WRITE_SYNC (Srinivas Eeda) [Orabug: 17342255]  
- ocfs2: fix NULL pointer dereference in ocfs2_duplicate_clusters_by_page v2 (Xiaowei.Hu) [Orabug: 14752693]  
- ocfs2: Fix oops in ocfs2_fast_symlink_readpage() code path (Xiaowei.Hu) [Orabug: 17342255]  
- ocfs2: ->rl_count endianness breakage (Al Viro) [Orabug: 17342255]  
- ocfs2: ->rl_used breakage on big-endian (Al Viro) [Orabug: 17342255]  
- Revert "ocfs2: Push out dropping of dentry lock to ocfs2_wq" (Sunil Mushran) [Orabug: 17342255]  
- Revert "ocfs2: Fix deadlock on umount" (Sunil Mushran) [Orabug: 17342255]  
- Revert "ocfs2: Don't oops in ocfs2_kill_sb on a failed mount" (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/cluster: Fix o2net_fill_node_map() (Sunil Mushran) [Orabug: 17342255]  
- ocfs2: Tighten free bit calculation in the global bitmap (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/trivial: Limit unaligned aio+dio write messages to once per day (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/trivial: Print message indicating unaligned aio+dio write (Sunil Mushran) [Orabug: 17342255]  
- ocfs2: update ocfs2 version (Tiger Yang) [Orabug: 17342255]  
- spec: only require libdtrace-ctf for kernel-uek-devel if with_dtrace is set (Jerry Snitselaar) [Orabug: 17477312]  
- dtrace: fix for psinfo allocation during execve (Kris Van Hees) [Orabug: 17407069]  
- kbuild/ctf: Use shell expansion, not $(wildcard ...), for CTF section copying. (Nick Alcock) [Orabug: 17445637]  
- kbuild/ctf: always build vmlinux when building CTF. (Jamie Iles) [Orabug: 17397200]  
- kbuild/dtrace: don't assume that bash is the shell. (Jamie Iles) [Orabug: 17397234]  
- block: Rate-limit failed I/O error message (Dave Kleikamp) [Orabug: 17370630]  
- block: Disable autoprotect (Martin K. Petersen) [Orabug: 17370630]  
- cdc-acm: Increase number of devices to 64 (Joe Jin) [Orabug: 17370630]  
- Parallel mtrr init between cpus (Zhenzhong Duan) [Orabug: 17370630]  
- sg: push file descriptor list locking down to per-device locking (Vaughan Cao) [Orabug: 17370630]  
- sg: checking sdp->detached isn't protected when open (Vaughan Cao) [Orabug: 17370630]  
- sg: no need sg_open_exclusive_lock (Vaughan Cao) [Orabug: 17370630]  
- sg: use rwsem to solve race during exclusive open (Vaughan Cao) [Orabug: 17370630]  
- Support checksum and gso offload of ipv6 in netback (Annie Li) [Orabug: 17370630]  
- net: init perm_addr in register_netdevice() (Jiri Pirko) [Orabug: 17370630]  
- drivers/cdrom/cdrom.c: use kzalloc() for failing hardware (Jonathan Salwan) [Orabug: 17370630] {CVE-2013-2164} 
- af_key: fix info leaks in notify messages (Mathias Krause) [Orabug: 17370630] {CVE-2013-2234} 

* Wed Sep 11 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-15.el6uek] 
- sparc64: strict_devmem configs (bob picco) [Orabug: 17442487]  
- sparc64: retry domain service registration (chris hyser) [Orabug: 17375532]  
- Btrfs: make the chunk allocator completely tree lockless (Josef Bacik) [Orabug: 17329252]  
- config: Disable memory hotplug support for Xen balloon driver (Daniel Kiper) [Orabug: 17343739]  
- Revert "SPEC: Do not sign modules, pro tem." (Jerry Snitselaar) [Orabug: 17410371]  
- config: enable snd-tea575x-tuner driver (Jerry Snitselaar) [Orabug: 17346564]  
- config: add missing wireless drivers to debug config (Jerry Snitselaar) [Orabug: 17346564]  
- Btrfs: set/change the label of a mounted file system (jeff.liu) [Orabug: 16745716]  
- Btrfs: Add a new ioctl to get the label of a mounted file system (jeff.liu) [Orabug: 16745716]  
- sparc64: __init code no longer called during non __init (chris hyser)   
- RDS: Port of UEK2 changes between 400.107.0 and 400.124.1 (Venkat Venkatsubra) [Orabug: 17320357]  

* Tue Sep 3 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-14.el6uek] 
- dm: allow error target to replace either bio-based and request-based targets (Joe Jin) [Orabug: 17405032]  
- dtrace: remove unnecessary exported symbol (Kris Van Hees) [Orabug: 17346878]  
- dtrace: Ensure that USDT probes are carried over correctly across fork(). (Kris Van Hees) [Orabug: 17346878]  
- dtrace: fix retrieval of arg5 through arg9 (Kris Van Hees) [Orabug: 17368166]  
- dtrace: Ensure that task_struct members are initialized correctly (Kris Van Hees)   
- Two efficiency fixes for audit mechanism (Dan Duval) [Orabug: 16765434]  
- Three fixes to audit_log_start() mechanism (Dan Duval) [Orabug: 167654341]  
- dtrace: ensure that builds in a separate objdir work (Kris Van Hees) [Orabug: 17369799]  
- config: align config options with uek2 (Jerry Snitselaar) [Orabug: 17346564]  
- dwarf2ctf: Ensure the CTF directory exists before writing the filelist. (Nick Alcock) [Orabug: 17363469]  
- dwarf2ctf: avoid command-line length limits by passing .o filenames via a file. (Nick Alcock) [Orabug: 17363469]  
- xen: initialize xen panic handler for PVHVM (Vaughan Cao) [Orabug: 17200031]  
- af_key: initialize satype in key_notify_policy_flush() (Nicolas Dichtel) [Orabug: 17370760] {CVE-2013-2237} 
- RDS: RDS NETFILTER SUPPORT (Ahmed Abbas) [Orabug: 17285666]  
- mods: don't put regular modules under extra/ (Jerry Snitselaar) [Orabug: 17347419]  
- b43: stop format string leaking into error msgs (Kees Cook) [Orabug: 16993114] {CVE-2013-2852} 

* Wed Aug 21 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-13.el6uek] 
- config: more updates (Jerry Snitselaar) [Orabug: 17248299]  

* Wed Aug 21 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-12.el6uek] 
- config: update configs (Jerry Snitselaar) [Orabug: 17248299]  
- fuse: return -EGAIN if not connected (Srinivas Eeda) [Orabug: 17337480]  
- fuse: split fuse queues to help numa systems (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- fuse: add fuse numa node struct (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- fuse: add numa mount option (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- config: remove lm80 driver to avoid possible crash (Jerry Snitselaar) [Orabug: 17337318]  
- kabi: update Module.kabi and kabi_whitelist for UEK3 (Jerry Snitselaar) [Orabug: 17335510]  
- config: clean up config files (Jerry Snitselaar) [Orabug: 17335515]  
- dtrace: DT_FASTTRAP should select UPROBE_EVENT (Jerry Snitselaar) [Orabug: 17325699]  
- turn on panic on oops and align configs (Maxim Uvarov)   
- acpi_i2c: set MODULE_LICENSE, MODULE_AUTHOR, and MODULE_DESCRIPTION (Jerry Snitselaar) [Orabug: 17321212]  
- Revert "cpuidle: Quickly notice prediction failure for repeat mode" (ethan.zhao) [Orabug: 17315729]  
- Revert "cpuidle: Quickly notice prediction failure in general case" (Rafael J. Wysocki) [Orabug: 17315729]  
- mm/vmalloc.c: fix an overflow bug in alloc_vmap_area() (Zhang Yanfei) [Orabug: 17315488]  
- ioat: Add alignment workaround for IVB platforms (Dave Jiang) [Orabug: 16495543]  
- cpufreq: Fix governor start/stop race condition (ethan.zhao) [Orabug: 17071478]  

* Thu Aug 15 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-11.el6uek] 
- sparc: sparc64_task_unmmaped_base and sparc64_task_size_max fix (Jerry Snitselaar)   
- config: remove unneeded ib config options in sparc build (Jerry Snitselaar) [Orabug: 17315304]  
- rds: fix build error for ib_recv.c (Jerry Snitselaar) [Orabug: 17315304]  
- kabi: Fix up Module.kabi_x86_64 (Jerry Snitselaar) [Orabug: 17309389]  
- Revert "dtrace: only do kallsyms build on x86_64" (Jerry Snitselaar) [Orabug: 17314140]  
- dtrace: Fix formatting mistake in spec file. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Fix for the argument validation code. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Include asm/current.h for the mutex_owned() fucntion. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Fix build requirements for the new kallsyms util; add requirements to -devel. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Bug fix for logic to determine the (inode, offset) pair for uprobes. (Kris Van Hees)   

* Tue Aug 13 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-10.el6uek] 
- mptfusion: fix kernel-doc build errors (Jerry Snitselaar) [Orabug: 17308655]  
- kabi: fix kabi check for builds (Jerry Snitselaar) [Orabug: 17308516]  

* Tue Aug 13 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-9.el6uek] 
- dtrace: only do kallsyms build on x86_64 (Jerry Snitselaar) [Orabug: 17308256]  
- kabi: Update Module.kabi_x86_64 (Jerry Snitselaar) [Orabug: 17302224]  
- Update lpfc version for 8.3.7.26.2p driver release (Gairy Grannum)   
- Enable BlockGuard Support (Vaios Papadimitriou)   
- Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (James Smart)   
- Update copyrights for 8.3.41 modifications (James Smart)   
- Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (James Smart)   
- Add first burst support to driver (James Smart)   
- Fixed the format of some log message fields (James Smart)   
- Add first burst support to driver (James Smart)   
- Fixed not able to perform PCI function reset when board was not in online mode (James Smart)   
- Fixed failure in setting SLI3 board mode (James Smart)   
- Fixed SLI3 failing FCP write on check-condition no-sense with residual zero (James Smart)   
- Fixed support for 128 byte WQEs (James Smart)   
- Ensure driver properly zeros unused fields in SLI4 mailbox commands (James Smart)   
- Fixed max value of lpfc_lun_queue_depth (James Smart)   
- Fixed Receive Queue varied frame size handling (James Smart)   
- Fix mailbox byteswap issue on PPC (James Smart)   
- Fixed freeing of iocb when internal loopback times out (James Smart)   
- lpfc 8.3.40: Update Copyrights to 2013 for 8.3.38, 8.3.39, and 8.3.40 modifications (James Smart)   
- lpfc 8.3.40: Fixed a race condition between SLI host and port failed FCF rediscovery (James Smart)   
- lpfc 8.3.40: Fixed issue mailbox wait routine failed to issue dump memory mbox command (James Smart)   
- treewide: Fix typos in kernel messages (Masanari Iida)   
- lpfc 8.3.40: Fixed system panic due to unsafe walking and deleting linked list (James Smart)   
- lpfc 8.3.40: Fixed FCoE connection list vlan identifier and add FCF list debug (James Smart)   
- lpfc 8.3.40: Clarified the behavior of the lpfc_max_luns module parameter (James Smart)   
- lpfc 8.3.40: Fix to allow OCM to report FEC status (James Smart)   
- lpfc 8.3.40: Fixed a missing return code in a logging message (James Smart)   
- lpfc 8.3.40: Fixed some logging message fields (James Smart)   
- lpfc 8.3.40: Fixed list corruption when lpfc_drain_tx runs (James Smart)   
- lpfc 8.3.40: Fix starting reference tag when calculating BG error (James Smart)   
- lpfc 8.3.40: Fix inconsistent list removal causes crash (James Smart)   
- lpfc 8.3.40: Fixed system panic during handling unsolicited receive buffer error condition (James Smart)   
- lpfc 8.3.40: Fix BlockGuard error checking (James Smart)   
- lpfc 8.3.40: Fixed crash during FCoE failover testing. (James Smart)   
- lpfc 8.3.40: Fix lpfc_used_cpu to be more dynamic (James Smart)   
- lpfc 8.3.39: Fixed driver handling of CLEAR_LA with NPIV enabled causing SID=0 frames out (James Smart)   
- scsi: fix lpfc build when wmb() is defined as mb() (Randy Dunlap)   
- lpfc 8.3.39: Reduced tmo value set to FLOGI WQE for quick recovery from FLOGI sequence timeout (James Smart)   
- lpfc 8.3.39: Add log message when completes with clean address bit set to zero (James Smart)   
- lpfc 8.3.39: Fixed driver vector mapping to CPU affinity (James Smart)   
- lpfc 8.3.39: Fixed driver vector mapping to CPU affinity (James Smart)   
- lpfc 8.3.39: Fixed iocb flags not being reset for scsi commands (James Smart)   
- lpfc 8.3.39: Fixed system panic during EEH recovery due to midlayer acting on outstanding I/O (James Smart)   
- lpfc 8.3.39: Fixed system panic during EEH recovery due to midlayer acting on outstanding I/O (James Smart)   
- lpfc 8.3.39: Fixed not returning FAILED status when SCSI invoking host reset handler failed (James Smart)   
- lpfc 8.3.39: Fixed bad book keeping in posting els sgls to port (James Smart)   
- lpfc 8.3.39: Fixed deadlock between hbalock and nlp_lock use (James Smart)   
- [SCSI] lpfc 8.3.39: Fixed BlockGuard to take advantage of rdprotect/wrprotect info when available (James Smart)   
- lpfc 8.3.39: Reduced spinlock contention on SCSI buffer list (James Smart)   
- lpfc 8.3.39: Fixed crash when processing bsg's sg list with high memory pages (James Smart)   
- lpfc 8.3.39: Remove lpfc_fcp_look_ahead module parameter (James Smart)   
- lpfc 8.3.39: Fix driver issues with SCSI Host reset (James Smart)   
- lpfc 8.3.39: Doorbell formation information logged in dual-chute mode WQ and RQ setup (James Smart)   
- lpfc 8.3.39: Fix driver issues with large s/g lists for BlockGuard (James Smart)   
- lpfc 8.3.39: Fix driver issues with large lpfc_sg_seg_cnt values (James Smart)   
- lpfc 8.3.39: Fixed pt2pt and loop discovery problems on topology changes. (James Smart)   
- lpfc 8.3.39: Remove driver dependency on HZ (James Smart)   
- lpfc 8.3.38: Fixed async FCF modified event to in-use FCF failure to trigger recovery (James Smart)   
- lpfc 8.3.39: Fixed BlockGuard error reporting (James Smart)   
- lpfc 8.3.39: Fixed VPI allocation issues after firmware dump is performed (James Smart)   
- lpfc 8.3.38: Fixed potential mis-interpretation of READ_TOPOLOGY reserved fields (James Smart)   
- lpfc 8.3.38: Fix default value for lpfc_enable_rrq. (James Smart)   
- lpfc 8.3.38: Fixed circular locking dependency and inconsistent lock state issues (James Smart)   
- lpfc 8.3.38: Fixed PT2PT bring up problem for FC SLI4. (James Smart)   
- lpfc 8.3.38: Fixed OXID reuse issue. (James Smart)   
- lpfc 8.3.38: Fixed async FCF modified event to in-use FCF failure to trigger recovery (James Smart)   
- lpfc 8.3.38: Fixed deadlock condition in FCF round robin handling (James Smart)   
- scsilpfc 8.3.38: Fixed bsg timeout handling issues that would result in crashes (James Smart)   
- lpfc 8.3.38: Fixed NMI watch dog panic's when resetting the hba. (James Smart)   
- lpfc 8.3.38: Fixed degraded performance after cable pulls (James Smart)   
- lpfc 8.3.37: Provide support for change_queue_type (James Smart)   
- lpfc: fix potential NULL pointer dereference in lpfc_sli4_rq_put() (Wei Yongjun)   
- lpfc 8.3.37: Fixed infinite loop in lpfc_sli4_fcf_rr_next_index_get. (James Smart)   
- lpfc 8.3.37: Fixed crash due to SLI Port invalid resource count (James Smart)   
- lpfc 8.3.37: Provide support for FCoE protocol dual-chute (ULP) operation (James Smart)   
- lpfc 8.3.37: Fixed stale ndlp state when the node is marked for deferred removal. (James Smart)   
- lpfc 8.3.37: Fix potential memory corruption bug (James Smart)   
- lpfc 8.3.37: Fixed no-context ABTS failed with BA_RJT (James Smart)   
- lpfc 8.3.37: Removed use of NOP mailboxes for interrupt verification (James Smart)   
- lpfc 8.3.37: Fixed exhausted retry for plogi to nameserver. (James Smart)   
- lpfc 8.3.37: Fixed ELS_REC received on the unsolicited receive queue (James Smart)   
- mptfusion: update to LSI version 4.28.20.03 (Jerry Snitselaar) [Orabug: 17307187]  
- turn on kabi check for x86 (Maxim Uvarov)   
- config: CONFIG_X86_INTERNODE_CACHE_SHIFT=7 (Maxim Uvarov)   
- kabi_whitelist_x86_64 (Maxim Uvarov)   
- Ensure memory allocation results are checked throughout the code. (Kris Van Hees)   
- net: sctp: fix NULL pointer dereference in socket destruction (Daniel Borkmann) [Orabug: 17071059]  
- mm: leave pmd_huge_pte when CONFIG_TRANSPARENT_HUGEPAGE disabled (Jerry Snitselaar) [Orabug: 17301856]  
- sparc64 - read_persistent_clock (bob picco)   
- ipv6: call udp_push_pending_frames when uncorking a socket with AF_INET pending data (Hannes Frederic Sowa) [Orabug: 17296551] {CVE-2013-4162} 
- ipv6: ip6_append_data_mtu did not care about pmtudisc and frag_size (Hannes Frederic Sowa) [Orabug: 17296420] {CVE-2013-4163} 
- dm mpath: fix ioctl deadlock when no paths (Hannes Reinecke)   
- dm mpath: enable WRITE SAME support (Mike Snitzer)   
- dm table: fix write same support (Mike Snitzer)   
- dm: rename request variables to bios (Alasdair G Kergon)   
- dm: clean up clone_bio (Alasdair G Kergon)   
- NVMe: Add MSI support (Ramachandra Rao Gajula)   
- NVMe: Use dma_set_mask() correctly (Matthew Wilcox)   
- Return the result from user admin command IOCTL even in case of failure (Chayan Biswas)   
- NVMe: Do not cancel command multiple times (Keith Busch)   
- NVMe: fix error return code in nvme_submit_bio_queue() (Wei Yongjun)   
- NVMe: check for integer overflow in nvme_map_user_pages() (Dan Carpenter)   
- NVMe: Fix a signedness bug in nvme_trans_modesel_get_mp (Vishal Verma)   
- NVMe: Remove redundant version.h header include (Sachin Kamat)   
- NVMe: Use user defined admin ioctl timeout (Keith Busch)   
- NVMe: Simplify Firmware Activate code slightly (Matthew Wilcox)   
- NVMe: Only clear the enable bit when disabling controller (Matthew Wilcox)   
- NVMe: Wait for device to acknowledge shutdown (Matthew Wilcox)   
- NVMe: Schedule timeout for sync commands (Keith Busch)   
- NVMe: Meta-data support in NVME_IOCTL_SUBMIT_IO (Keith Busch)   
- NVMe: Device specific stripe size handling (Keith Busch)   
- NVMe: Split non-mergeable bio requests (Keith Busch)   
- NVMe: Remove dead code in nvme_dev_add (Keith Busch)   
- NVMe: Check for NULL memory in nvme_dev_add (Keith Busch)   
- NVMe: Fix error clean-up on nvme_alloc_queue (Keith Busch)   
- NVMe: Free admin queue on request_irq error (Keith Busch)   
- NVMe: Add scsi unmap to SG_IO (Keith Busch)   
- NVMe: queue usage fixes in nvme-scsi (Keith Busch)   
- NVMe: Set TASK_INTERRUPTIBLE before processing queues (Arjan van de Ven)   
- NVMe: Add a character device for each nvme device (Keith Busch)   
- NVMe: Fix endian-related problems in user I/O submission path (Matthew Wilcox)   
- NVMe: Fix I/O cancellation status on big-endian machines (Matthew Wilcox)   
- NVMe: Fix sparse warnings in scsi emulation (Vishal Verma)   
- NVMe: Don't fail initialisation unnecessarily (Matthew Wilcox)   
- NVMe: Abstract out sector to block number conversion (Matthew Wilcox)   
- NVMe: Use round_jiffies_relative() for the periodic, once-per-second timer (Arjan van de Ven)   
- NVMe: Add nvme-scsi.c (Vishal Verma)   
- NVMe: Add definitions for format command (Vishal Verma)   
- NVMe: Move structures & definitions to header file (Vishal Verma)   
- NVMe: Rename nvme.c to nvme-core.c (Vishal Verma)   
- NVMe: Add discard support for capable devices (Keith Busch)   
- NVMe: Add namespaces with no LBA range feature (Keith Busch)   
- NVMe: Initialize iod nents to 0 (Keith Busch)   
- NVMe: Define SMART log (Keith Busch)   
- NVMe: Add result to nvme_get_features (Keith Busch)   
- NVMe: Set result from user admin command (Keith Busch)   
- NVMe: End queued bio requests when freeing queue (Keith Busch)   
- NVMe: Free cmdid on nvme_submit_bio error (Keith Busch)   
- oracleasm: Compat changes for 3.8 (Martin K. Petersen)   
- oracleasm: Introduce module parameter for block size selection (Martin K. Petersen) [Orabug: 15924773]  
- oracleasm: Data integrity support (Martin K. Petersen)   
- oracleasm: Fix two merge errors (Martin K. Petersen)   
- Oracle ASM Kernel Driver (Martin K. Petersen)   
- megaraid_sas: Big endian support (Martin K. Petersen)   
- megaraid: fix BUG_ON() from incorrect use of delayed work (Xiaotian Feng)   
- aerdrv: Enhanced AER logging (Lance Ortiz) [Orabug: 17293976]  
- aerdrv: Trace Event for PCI Express Advanced Error Reporting (Lance Ortiz) [Orabug: 17293976]  
- [SCSI] scsi_dh_alua: Add module parameter to allow failover to non preferred path without STPG (Stewart, Sean)   
- [SCSI] Don't attempt to send extended INQUIRY command if skip_vpd_pages is set (Martin K. Petersen)   
- [SCSI] sd: Update WRITE SAME heuristics (Martin K. Petersen)   
- [SCSI] 3w-xxxx: Create sense buffer for unsupported commands (Martin K. Petersen)   
- [SCSI] Workaround for disks that report bad optimal transfer length (Martin K. Petersen)   
- [SCSI] Allow error handling timeout to be specified (Martin K. Petersen)   
- [SCSI] scsi_dh_alua: fix stpg sense handling (Mike Christie)   
- [SCSI] sd_dif: problem with verify of type 1 protection information (PI) (Jeremy Higdon)   
- [SCSI] sd: avoid deadlocks when running under multipath (Hannes Reinecke)   
- x86/mce: Rework cmci_rediscover() to play well with CPU hotplug (Srivatsa S. Bhat) [Orabug: 17293976]  
- ACPI / APEI: fix error return code in ghes_probe() (Wei Yongjun) [Orabug: 17293976]  
- hwmon: (adm1021) Strengthen chip detection for ADM1021, LM84 and MAX1617 (Guenter Roeck) [Orabug: 17293976]  
- fnic: update from mainline 1.5.0.2 to cisco 1.5.0.45 (Jerry Snitselaar) [Orabug: 17293525]  
- cgroup: fix bogus kernel warnings when cgroup_create() failed (Li Zefan) [Orabug: 16448051]  
- cgroup: remove a NULL check in cgroup_exit() (Li Zefan) [Orabug: 16448051]  
- cgroup: fix cgroup_path() vs rename() race (Li Zefan) [Orabug: 16448051]  
- cgroup: fix cgroup_rmdir() vs close(eventfd) race (Li Zefan) [Orabug: 16448051]  
- cgroup: fail if monitored file and event_control are in different cgroup (Li Zefan) [Orabug: 16448051]  
- cgroup: fix a subtle bug in descendant pre-order walk (Tejun Heo) [Orabug: 16448051]  
- memcg: do not create memsw files if swap accounting is disabled (Michal Hocko) [Orabug: 16448051]  
- memcg: initialize kmem-cache destroying work earlier (Konstantin Khlebnikov) [Orabug: 16448051]  
- mm: memcg: remove incorrect VM_BUG_ON for swap cache pages in uncharge (Johannes Weiner) [Orabug: 16448051]  
- memcg: fix memcg_cache_name() to use cgroup_name() (Michal Hocko) [Orabug: 16448051]  
- blkcg: fix "scheduling while atomic" in blk_queue_bypass_start (Jun'ichi Nomura) [Orabug: 16448051]  
- device_cgroup: don't grab mutex in rcu callback (Jerry Snitselaar) [Orabug: 16448051]  
- l2tp: prevent tunnel creation on netns mismatch (Tom Parkin) [Orabug: 16448051]  
- netns: fdb: allow unprivileged users to add/del fdb entries (Gao feng) [Orabug: 16448051]  
- netns: ebtable: allow unprivileged users to operate ebtables (Gao feng) [Orabug: 16448051]  
- netns: bridge: allow unprivileged users add/delete mdb entry (Gao feng) [Orabug: 16448051]  
- netns: bond: allow unprivileged users to control bond device (Gao feng) [Orabug: 16448051]  
- netfilter: nf_ct_reasm: fix per-netns sysctl initialization (Michal Kubeček) [Orabug: 16448051]  
- config: enable CONFIG_XFS_WARN for debug builds (Jerry Snitselaar) [Orabug: 17271899]  
- xfs: introduce CONFIG_XFS_WARN (Dave Chinner) [Orabug: 17271899]  
- xfs: recheck buffer pinned status after push trylock failure (Brian Foster) [Orabug: 17271899]  
- xfs: remove log force from xfs_buf_trylock() (Brian Foster) [Orabug: 17271899]  
- xfs: ensure we capture IO errors correctly (Dave Chinner) [Orabug: 17271899]  
- xfs: fallback to vmalloc for large buffers in xfs_attrlist_by_handle (Eric Sandeen) [Orabug: 17271899]  
- xfs: fallback to vmalloc for large buffers in xfs_compat_attrlist_by_handle (Eric Sandeen) [Orabug: 17271899]  
- ext4: fix corruption when online resizing a fs with 1K block size (Maarten ter Huurne) [Orabug: 17279036]  
- ext4: fix data integrity for ext4_sync_fs (Jerry Snitselaar) [Orabug: 17279036]  
- ext4: fix overflow when counting used blocks on 32-bit architectures (Jan Kara) [Orabug: 17279036]  
- ext4: fix data offset overflow in ext4_xattr_fiemap() on 32-bit archs (Jan Kara) [Orabug: 17279036]  
- ext4: fix overflows in SEEK_HOLE, SEEK_DATA implementations (Jerry Snitselaar) [Orabug: 17279036]  
- ext4: fix data offset overflow on 32-bit archs in ext4_inline_data_fiemap() (Jan Kara) [Orabug: 17279036]  
- ext4: fix type-widening bug in inode table readahead code (Theodore Ts'o) [Orabug: 17279036]  
- ext4: mext_insert_extents should update extent block checksum (Darrick J. Wong) [Orabug: 17279036]  
- ext4: fix deadlock with quota feature (Jan Kara) [Orabug: 17279036]  
- qlcnic: update from 5.0.30 to 5.2.43 (Jerry Snitselaar) [Orabug: 17267160]  
- Remove pre-alpha features for release. (Kris Van Hees) [Orabug: 17076008]  
- CONFIG_UPROBES is needed by CONFIG_DT_FASTTRAP, not CONFIG_DTRACE. (Nick Alcock) [Orabug: 17076008]  
- CONFIG_DTRACE should depend on CONFIG_UPROBES. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Include all sources regardless of arch. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Changes for UEK merge. (Nick Alcock) [Orabug: 17076008]  
- Fix loss of error code from waitid() when info is provided. (Nick Alcock) [Orabug: 17076008]  
- Make old_rsp available to kernel modules. (Kris Van Hees) [Orabug: 17076008]  
- waitfd selftest: dike out some dead code. (Nick Alcock) [Orabug: 17076008]  
- Introduce poll_wait_fixed(), and use it in waitfds. (Nick Alcock) [Orabug: 17076008]  
- No longer reference 'ctf.ko.unsigned' in CTF debuginfo stripping machinery. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Do not sign modules, pro tem. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Fix the -g1 debuginfo hack. (Nick Alcock) [Orabug: 17076008]  
- Add waitfd(), and a testcase for it. (Nick Alcock) [Orabug: 17076008]  
- Ensure that arg6 through arg9 get retrieved correctly for USDT probes. (Kris Van Hees) [Orabug: 17076008]  
- Finish the implementation of is-enabled USDT probes. (Kris Van Hees) [Orabug: 17076008]  
- Fixes for tracepoint cleanup. (Kris Van Hees) [Orabug: 17076008]  
- Remove unnecessary debugging output. (Kris Van Hees) [Orabug: 17076008]  
- Update syscall tracing in view of Linux 3.8 changes. (Kris Van Hees) [Orabug: 17076008]  
- USDT implementation (phase 2). (Kris Van Hees) [Orabug: 17076008]  
- Revamp and split up DTrace headers.  Add ioctl() debugging machinery. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: blacklist certain structure members entirely. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Repair faulty indentation. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Split the absolute-file-name caching machinery out of type_id(). (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: sentinelize str_appendn(). (Nick Alcock) [Orabug: 17076008]  
- ptrace: Add PTRACE_GETMAPFD. (Nick Alcock) [Orabug: 17076008]  
- Update execve() syscall probe support. (Kris Van Hees) [Orabug: 17076008]  
- Add support for an SDT probe getting called from multiple functions. (Kris Van Hees) [Orabug: 17076008]  
- Move SDT call location for surrender probe. (Kris Van Hees) [Orabug: 17076008]  
- USDT implementation (Phase 1). (Kris Van Hees) [Orabug: 17076008]  
- Remove incorrect FBT support code. (Kris Van Hees) [Orabug: 17076008]  
- Move psinfo to its own header file. (Kris Van Hees) [Orabug: 17076008]  
- Update copyright statements. (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: Update the shared CTF file right after initialization. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Improve debugging and indentation fixes. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf doc revisions. (Nick Alcock) [Orabug: 17076008]  
- Internal performance measurement support code. (Kris Van Hees) [Orabug: 17076008]  
- Disable KVM steal-time accounting when DTrace is in use. (Nick Alcock) [Orabug: 17076008]  
- Cosmetic improvements to CTF linking. (Nick Alcock) [Orabug: 17076008]  
- Remove a few obsolete probes. (Kris Van Hees) [Orabug: 17076008]  
- Cater for changes in the way the kernel is linked. (Kris Van Hees) [Orabug: 17076008]  
- Miscellaneous 3.6 porting work. (Kris Van Hees) [Orabug: 17076008]  
- Fix up rq.dtrace_cpu_info member. (Kris Van Hees) [Orabug: 17076008]  
- gitignore: Ignore objects.builtin and dwarf2ctf. (Nick Alcock) [Orabug: 17076008]  
- Fix outright typos in the 3.6 forward-port. (Nick Alcock) [Orabug: 17076008]  
- Remove obsolete static probe documentation. (Kris Van Hees) [Orabug: 17076008]  
- DTrace-independent CTF. (Nick Alcock) [Orabug: 17076008]  
- Do not build in CTF data for no-longer-built-in modules. (Nick Alcock) [Orabug: 17076008]  
- Document dwarf2ctf. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Extend the deduplication blacklist. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Improve error message on internal deduplication error. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Note a future enhancement. (Nick Alcock) [Orabug: 17076008]  
- Document parameters to die_to_ctf(). (Nick Alcock) [Orabug: 17076008]  
- Do not construct objects.builtin if CTF is not being built. (Nick Alcock) [Orabug: 17076008]  
- Do not build dwarf2ctf nor attempt to use it if !CONFIG_DTRACE. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Rename the DTrace kernel to kernel-uek-dtrace-. (Nick Alcock) [Orabug: 17076008]  
- SPEC: strip kernel modules using objcopy, not eu-strip (Nick Alcock) [Orabug: 17076008]  
- SPEC: do not strip non-debugging sections from kernel modules. (Nick Alcock) [Orabug: 17076008]  
- SPEC: build firmware. (Nick Alcock) [Orabug: 17076008]  
- Additional action support (and bug fixes). (Kris Van Hees) [Orabug: 17076008]  
- Get rid of debugging code. (Kris Van Hees) [Orabug: 17076008]  
- Add psinfo/cpuinfo OS level support. (Kris Van Hees) [Orabug: 17076008]  
- Removed debugging output (1 line). (Kris Van Hees) [Orabug: 17076008]  
- Change the DTrace startup handling (at boot time) for SDT. (Kris Van Hees) [Orabug: 17076008]  
- Cleanup (and adding) of SDT probe points. (Kris Van Hees) [Orabug: 17076008]  
- Write the CTF files for standalone modules to a subdir of the module directory. (Nick Alcock) [Orabug: 17076008]  
- Adapt to the libdtrace-ctf devel package split. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: unnamed structure/union support. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: recurse_ctf() -> die_to_ctf(). (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: fix the signed-modules case. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: correctly propagate IDs for array types. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: fix off-by-one in emitted array bounds. (Nick Alcock) [Orabug: 17076008]  
- Fix tiny comment typo. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: blacklist certain modules from deduplication. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: include enumeration types inside functions. (Nick Alcock) [Orabug: 17076008]  
- New IO provider probes: start, done, wait-start, wait-done New sched provides probes: enqueue, dequeue, wakeup, preempt, remain-cpu, change-pri, surrender (Note that the preempt probe currently passes a debugging argument that will be removed in the future to match the argument-less version in the documentation.) (Kris Van Hees) [Orabug: 17076008]  
- Fix to handle multiple SDT-based probes in a single function. (Kris Van Hees) [Orabug: 17076008]  
- DTrace: require assembler symbol stripping and debug info. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Fix array dimensions. (Nick Alcock) [Orabug: 17076008]  
- Change the name of the CTF section in kernel modules. (Nick Alcock) [Orabug: 17076008]  
- Fix a bug in the SDT probe location generator, where it could accidentally add the address of a non-function identifier to the SDT list (e.g. watchdog occurs both in the uninitialised data section (BSS) and the text section). (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: major duplicate detection fixes. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: optimize type_id() and fix array dimension lookup. (Nick Alcock) [Orabug: 17076008]  
- Changed the logic for determining SDT probe point locations because the previous version did not account for probes that might be placed in non-.text segments.  New code also avoids extra passes that were not necessary. (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: store away the types and names of non-static global variables. (Nick Alcock) [Orabug: 17076008]  
- Set the name of the parent of child modules to "dtrace_ctf". (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: clarify comments, improve a type name. (Nick Alcock) [Orabug: 17076008]  
- Force dtrace_ctf.ko to be loaded whenever dtrace.ko is. (Nick Alcock) [Orabug: 17076008]  
- Generate CTF information for the kernel. (Nick Alcock) [Orabug: 17076008]  
- Drop rogue debugging statements. (Nick Alcock) [Orabug: 17076008]  
- Provide symbol sizes in /proc/kallmodsyms. (Nick Alcock) [Orabug: 17076008]  
- Add a dummy dtrace_ctf.ko module. (Nick Alcock) [Orabug: 17076008]  
- Fix /proc/kallmodsyms population bugs. (Nick Alcock) [Orabug: 17076008]  
- kallsyms: work in a clean tree, and a non-modular tree. (Nick Alcock) [Orabug: 17076008]  
- kallsyms: work with older glibc. (Nick Alcock) [Orabug: 17076008]  
- Don't depend on dtrace-user. (Nick Alcock) [Orabug: 17076008]  
- Add /proc/kallmodsyms. (Nick Alcock) [Orabug: 17076008]  
- - sched-tick SDT probe. - FBT probe point discovery and probe creation. - Moving code around for the kernel pseudo-module handling since it gets used   by both the SDT code and the FBT code. (Kris Van Hees) [Orabug: 17076008]  
- Delete an obsolete release script. (Nick Alcock) [Orabug: 17076008]  
- Changed from using mutex_is_locked() to a new mutex_owned(), in support of the Solaris MUTEX_HELD() macro.  The former was merely testing whether the mutex was locked, whereas the real test needed here is whether the mutex is held by the current thread. (Kris Van Hees) [Orabug: 17076008]  
- Fix signed division and modulo operations in DIF. Ensure that SDT probe points are patched with a NOP sequence at boot time. Remove debugging output during SDT registration. (Kris Van Hees) [Orabug: 17076008]  
- Make sure the insn length is initialized in the right branch of the die notifier. (Nick Alcock) [Orabug: 17076008]  
- Ensure that the trap handler is regisstered only once. Register with first use, (Kris Van Hees) [Orabug: 17076008]  
- Ensure that the die notifier hook is installed whenever DTrace is enabled, since page fault and general protection fault handling depends on it, and that is needed for safe memory access support in DTrace. (Kris Van Hees) [Orabug: 17076008]  
- Adding missing files for PF/GPF support. (Kris Van Hees) [Orabug: 17076008]  
- Support for page fault and general protection fault detection for DTrace, to ensure that DTrace memory access faults are non-fatal. (Kris Van Hees) [Orabug: 17076008]  
- Fix incorrect probe point name. (Kris Van Hees) [Orabug: 17076008]  
- Added lwp-exit and lwp-create SDT probe points. Change the DRELOC tag in make output to DT-SDT. (Kris Van Hees) [Orabug: 17076008]  
- SDT implementation (core kernel support for providing a list of static probe points for the kernel pseudo-module, dtrace SDT meta-provider support, ...). Also, new script (dtrace_sdt.sh) to extract locations of SDT probe points in the core kernel. (Kris Van Hees) [Orabug: 17076008]  
- Enable processing the SDT probe point info at boot time (before SMP is actually enabled), if DTrace SDT support has been enabled (built-in or as module).  For now, provide some verbose info on the probe points getting resolved. (Kris Van Hees) [Orabug: 17076008]  
- Fix resolving addresses of relocation records for SDT probe points.  The addresses were being calculated based on the wrong starting point (_stext whereas it ought to be _text), and the base was not taken into account. Fixed the writing of NOPs in the location of the probe point calls, since the existing case was causing kernel paging faults.  Made the add_nops() function in alternative.c non-static so it can be used in sdt_register. Use add_nops() to select the most appropriate NOP sequence for replacing the probe point call, and write the NOPs using text_poke(). (Kris Van Hees) [Orabug: 17076008]  
- Fixed the allocation of cyclics that was the cuase for some obscure crashes during the testsuite execution.  Problem was that cyclics were being allocated in chunks, with a new array being allocated as (prev-size + chink-size), and then the old entries being copied over.  However, because the hrtimer struct is embedded in the cyclic struct, this meant that hrtimer structs were being moved outside the hrtimer code. (Kris Van Hees) [Orabug: 17076008]  
- Removed dead code (was #if 0 ... #endif).  Cleaned up ;; -> ;. (Kris Van Hees) [Orabug: 17076008]  
- Implementation for tracing stub-based system calls.  Due to the need for specialized code handling (mainly passing in a pt_regs structure as one of the arguments), some syscalls are called through a stub in assembly code. We duplicate the stub cdode in dtrace_stubs_x86_64.S, but instead of calling the actual syscall implementation code call our own syscall-specific handler, which ensures that entry and return probes are called as enabled, and then call the underlying implementation directly for handling the syscall. (Kris Van Hees) [Orabug: 17076008]  
- Allow for pushes of multiple branches and pushes of merged-back branches. (Nick Alcock) [Orabug: 17076008]  
- Remove some debugging that crept in. (Nick Alcock) [Orabug: 17076008]  
- Fix git commit URL. (Nick Alcock) [Orabug: 17076008]  
- push-dtrace-release: Fix argument checking. (Nick Alcock) [Orabug: 17076008]  
- Do not rely on 'git clone --branch'. (Nick Alcock) [Orabug: 17076008]  
- Release-pushing script. (Nick Alcock) [Orabug: 17076008]  
- Stacktrace dumping has been moved to the GPL-licensed dtrace_os.c because it depends on a symbol that is exported as GPL-only.  Functionality in dtrace_isa that requires stacktrace dumping can now use dtrace_stacktrace(). (Kris Van Hees) [Orabug: 17076008]  
- Fix porting issues from 2.6.32 to 2.6.39. Disable stub_* based syscalls (for now). (Kris Van Hees) [Orabug: 17076008]  
- Move cyclic.h into include/linux. (Nick Alcock) [Orabug: 17076008]  
- Finish GPL/CDDL splitting work. (Nick Alcock) [Orabug: 17076008]  
- CDDL copyrights for everything needing it. (Nick Alcock) [Orabug: 17076008]  
- Migrate dtrace to a standalone module, situated at the top level of the tree. (Nick Alcock) [Orabug: 17076008]  
- Fix walltimestamp. (Nick Alcock) [Orabug: 17076008]  
- Changes in how we collect the names o system calls.  Used to use the ftrace syscall meta info and the nr-to-meta functionality.  Now populates the systrace info structure statically at kernel compile time.  This means that the DTrace code no longer depends on ftrace. (Kris Van Hees) [Orabug: 17076008]  
- No more use for ktime_get_nongpl().  We an now use dtrace_gethrtime(). (Kris Van Hees) [Orabug: 17076008]  
- Implementation for syscall entry/return probes.  Makes the sys call table writable, and replaces the function pointer for select syscalls with the address of a wrapper function to enable entry and return probe firing. (Kris Van Hees) [Orabug: 17076008]  
- Conflict with CONFIG_DEBUG_LOCK_ALLOC. (Nick Alcock) [Orabug: 17076008]  
- Dependency fixes for dtrace. (Nick Alcock) [Orabug: 17076008]  
- Added CONFIG_DT_DEBUG_MUTEX option to enable printing all locations where a mutex is locked and unlocked. Implemented aggregations using the idr mechanism rather than the Solaris-based 1-byte allocation technique to get unique IDs. Various cleanup and small changes. (Kris Van Hees) [Orabug: 17076008]  
- Update sdt provider (sdt_mod.c) with lots of functions. NOTES: - module loadcnt may need more work. - kernel_searchsym() is incomplete (see FIXMEs). Add sdt_subr.c and build it in Makefile. Add str_impl.h for internal sdt use. Add more fields to linux/module.h for static probe bookkeeping. (Randy Dunlap) [Orabug: 17076008]  
- Add dtrace_module_loaded() and dtrace_module_unloaded(). Give the static probes in the kernel image a module name of   "kernel_builtins" and a module state of LIVE. Fix an extra-paren typo in dtrace_dev.c. NOTE:  This is incomplete.  There are a few TBDs and FIXMEs   in this patch. (Randy Dunlap) [Orabug: 17076008]  
- Turn on gcov profiliing for the RPM builds by default. (Nick Alcock) [Orabug: 17076008]  
- Turn on gcov profiling in the kernel/dtrace directory by default. (Nick Alcock) [Orabug: 17076008]  
- Adding framework for a test provider that fires a specific probe on request. Adding previously missing (and unused) exported functions: (Kris Van Hees) [Orabug: 17076008]  
- File needed for rpm builds to ensure DTrace is enabled as modules. (Kris Van Hees) [Orabug: 17076008]  
- add Documentation/dtrace_static_probes.txt, which is a directory of all static probes in the kernel tree. (Randy Dunlap) [Orabug: 17076008]  
- Remove license and add copyright. (Randy Dunlap) [Orabug: 17076008]  
- Build sdt_register.c into the kernel. (Nick Alcock) [Orabug: 17076008]  
- Add missing include needed for DTrace probes. (Nick Alcock) [Orabug: 17076008]  
- - convert relative probepoint relocation addresses to absolute:   this should have been done by the top-level Makefile, but it must   have a dependency problem since the generated vmlinux_info.S has   the correct info in it but the vmlinux_info.o file does not AND   the .S file was created AFTER the .o file. - convert calls to dtrace stub RETs to NOPs; (Randy Dunlap) [Orabug: 17076008]  
- Add some dtrace static probes that are easy to trigger. See the static probes directory listing for a summary of all dtrace static probes. (Randy Dunlap) [Orabug: 17076008]  
- Added dependency for FTRACE and FTRACE_SYSCALLS for the SYSTRACE provider. (Kris Van Hees) [Orabug: 17076008]  
- Remove debugging statements. (Kris Van Hees) [Orabug: 17076008]  
- Reduce the unintended ordering dependency (_text before _stext) when scanning the relocs info file. (Randy Dunlap) [Orabug: 17076008]  
- Adding debug code to track probe processing through BEGIN probe enabling. Adding minimal implementation of cyclic functionality (based on hrtimer) as an additional to the core kernel, linked in when dtrace is enabled (be it as module, or compiled in).  Exports cyclic_add() and cyclic_remove(). Removed former cyclic stub implementation (cyclic.c). (Kris Van Hees) [Orabug: 17076008]  
- The systrace provider depends on the FTRACE_SYSCALLS kernel feature. The systrace provider is actually called syscall on Solaris, so it has been renamed on the Linux side (i.e. it registers itself as syscall). Added some debug statements to track probe searches better. The probes/probematch ioctl handling should return -ESRCH when the last hit has been returned already. (Kris Van Hees) [Orabug: 17076008]  
- Reading the dtrace relocation info table could fail on a boundary condition. Fix by counting the string terminator (null) byte.  Now works for my 4 test cases. (Randy Dunlap) [Orabug: 17076008]  
- Read and use the _stext value for adding to relative relocation info to make it absolute. This works for my 4 test cases.  It was derived by examination and discovery.  There could be cases where it does not work, e.g. in other text sections. (Randy Dunlap) [Orabug: 17076008]  
- Removed || CONFIG_DT_SDT_MODULE from conditional surrounding call to dtrace_register_builtins() because that function does not exist in the kernel proper when DTrace is compiled as kernel modules. (Kris Van Hees) [Orabug: 17076008]  
- Add missing files (present in the CVS repo but not in git). (Kris Van Hees) [Orabug: 17076008]  
- systrace uses syscall_nr_to_meta, which is only available when FTRACE_SYSCALLS is enabled, so make systrace depend on FTRACE_SYSCALLS. (Randy Dunlap) [Orabug: 17076008]  
- Test push. (Kris Van Hees) [Orabug: 17076008]  
- Test commit (reverting previous test commit). (Kris Van Hees) [Orabug: 17076008]  
- Just a very small change to check whether git push will work fine by someone other than Nix. (Kris Van Hees) [Orabug: 17076008]  
- Initial import of DTrace kernelspace code. (Nick Alcock) [Orabug: 17076008]  

* Thu Aug 8 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-8.el6uek] 
- ipoib fix compilation if rcu debug enabled (Maxim Uvarov)   
- qlge: update from v1.00.00.31 to v1.00.00.32 (Jerry Snitselaar) [Orabug: 17267206]  
- qla2xxx: update from mainline 8.04.00.08-k to qlogic version 8.05.00.03.39.0-k (Saurav Kashyap) [Orabug: 17277380]  
- config file change for eIPoIB (Ajaykumar Hotchandani)   
- bnx2i: update from mainline version 2.7.2.2 to broadcom version 2.7.6.1d (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2fc: update from mainline version 1.0.12 to broadcom version 2.3.4 (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2x: update from mainline version 1.78.00-0 to broadcom version 1.76.54 (Jerry Snitselaar) [Orabug: 17024889]  
- cnic: update from mainline version 2.5.16 to broadcom version 2.5.16g (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2: update from mainline version 2.2.3 to broadcom version 2.2.3n (Jerry Snitselaar) [Orabug: 17024889]  
- tg3: update from mainline version 3.128 to broadcom version 3.131d (Jerry Snitselaar) [Orabug: 17024889]  
- tmpfs: add support for read_iter and write_iter (Hugh Dickins) [Orabug: 16371286]
- ubifs: convert file ops from aio_read/write to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- ecrpytfs: Convert aio_read/write ops to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- afs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- udf: convert file ops from aio_read/write to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- gfs2: Convert aio_read/write ops to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- xfs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- block_dev: add support for read_iter, write_iter (Asias He) [Orabug: 16371286]
- btrfs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- nfs: simplify swap (Dave Kleikamp) [Orabug: 16371286]
- nfs: add support for read_iter, write_iter (Dave Kleikamp) [Orabug: 16371286]
- ext4: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- ocfs2: add support for read_iter, write_iter, and direct_IO_bvec (Zach Brown) [Orabug: 16371286]
- fs: add read_iter and write_iter to several file systems (Dave Kleikamp) [Orabug: 16371286]
- fs: use read_iter and write_iter rather than aio_read and aio_write (Dave Kleikamp) [Orabug: 16371286]
- fs: create file_readable() and file_writable() functions (Dave Kleikamp) [Orabug: 16371286]
- loop: use aio to perform io on the underlying file (Zach Brown) [Orabug: 16371286]
- bio: add bvec_length(), like iov_length() (Zach Brown) [Orabug: 16371286]
- aio: add aio support for iov_iter arguments (Zach Brown) [Orabug: 16371286]
- aio: add aio_kernel_() interface (Zach Brown) [Orabug: 16371286]
- fs: pull iov_iter use higher up the stack (Zach Brown) [Orabug: 16371286]
- dio: add bio_vec support to __blockdev_direct_IO() (Dave Kleikamp) [Orabug: 16371286]
- dio: Convert direct_IO to use iov_iter (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: let callers extract iovecs and bio_vecs (Zach Brown) [Orabug: 16371286]
- iov_iter: add a shorten call (Zach Brown) [Orabug: 16371286]
- iov_iter: add bvec support (Zach Brown) [Orabug: 16371286]
- iov_iter: ii_iovec_copy_to_user should pre-fault user pages (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: hide iovec details behind ops function pointers (Zach Brown) [Orabug: 16371286]
- fuse: convert fuse to use iov_iter_copy_[to|from]_user (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: add __iovec_copy_to_user() (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: add copy_to_user support (Zach Brown) [Orabug: 16371286]
- iov_iter: iov_iter_copy_from_user() should use non-atomic copy (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: move into its own file (Zach Brown) [Orabug: 16371286]
- sparc64 - color correction (bob picco)   
- [ixgbe] hold rcu_read_lock() when derefencing rcu (Maxim Uvarov) [Orabug: 17213023]  
- mutex: Back out architecture specific check for negative mutex count (Waiman Long) [Orabug: 17237224]  
- mutex: Queue mutex spinners with MCS lock to reduce cacheline contention (Waiman Long) [Orabug: 17237224]  
- mutex: Make more scalable by doing less atomic operations (Waiman Long) [Orabug: 17237224]  
- mutex: Move mutex spinning code from sched/core.c back to mutex.c (Waiman Long) [Orabug: 17237224]  
- ipc/sem.c: Fix missing wakeups in do_smart_update_queue() (Manfred Spraul) [Orabug: 17237239]  
- ipc,sem: fix semctl(..., GETNCNT) (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: fix semctl(..., GETZCNT) (Rik van Riel) [Orabug: 17237239]  
- ipc: simplify rcu_read_lock() in semctl_nolock() (Linus Torvalds) [Orabug: 17237239]  
- ipc: simplify semtimedop/semctl_main() common error path handling (Linus Torvalds) [Orabug: 17237239]  
- ipc: move sem_obtain_lock() rcu locking into the only caller (Linus Torvalds) [Orabug: 17237239]  
- ipc: fix double sem unlock in semctl error path (Linus Torvalds) [Orabug: 17237239]  
- ipc: move the rcu_read_lock() from sem_lock_and_putref() into callers (Linus Torvalds) [Orabug: 17237239]  
- ipc: sem_putref() does not need the semaphore lock any more (Linus Torvalds) [Orabug: 17237239]  
- ipc: move rcu_read_unlock() out of sem_unlock() and into callers (Linus Torvalds) [Orabug: 17237239]  
- ipc: fix GETALL/IPC_RM race for sysv semaphores (Al Viro) [Orabug: 17237239]  
- ipc/msg.c: use list_for_each_entry_[safe] for list traversing (Nikola Pajkovsky) [Orabug: 17237239]  
- ipc,sem: fine grained locking for semtimedop (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: have only one list in struct sem_queue (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: open code and rename sem_lock (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: do not hold ipc lock more than necessary (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: introduce lockless pre_down ipcctl (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: introduce obtaining a lockless ipc object (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: remove bogus lock comment for ipc_checkid (Davidlohr Bueso) [Orabug: 17237239]  
- ipc/msgutil.c: use linux/uaccess.h (HoSung Jung) [Orabug: 17237239]  
- ipc: refactor msg list search into separate function (Peter Hurley) [Orabug: 17237239]  
- ipc: simplify msg list search (Peter Hurley) [Orabug: 17237239]  
- ipc: implement MSG_COPY as a new receive mode (Peter Hurley) [Orabug: 17237239]  
- ipc: remove msg handling from queue scan (Peter Hurley) [Orabug: 17237239]  
- ipc: set EFAULT as default error in load_msg() (Peter Hurley) [Orabug: 17237239]  
- ipc: tighten msg copy loops (Peter Hurley) [Orabug: 17237239]  
- ipc: separate msg allocation from userspace copy (Peter Hurley) [Orabug: 17237239]  
- ipc: clamp with min() (Peter Hurley) [Orabug: 17237239]  
- rwsem: check counter to avoid cmpxchg calls (Davidlohr Bueso) [Orabug: 17237186]  
- rwsem: no need for explicit signed longs (Davidlohr Bueso) [Orabug: 17237186]  
- x86 rwsem: avoid taking slow path when stealing write lock (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: do not block readers at head of queue if other readers are active (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: implement support for write lock stealing on the fastpath (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify __rwsem_do_wake (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: skip initial trylock in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: avoid taking wait_lock in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: use cmpxchg for trying to steal write lock (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: more agressive lock stealing in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify rwsem_down_read_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: move rwsem_down_failed_common code into rwsem_down_{read,write}_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: shorter spinlocked section in rwsem_down_failed_common() (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: make the waiter type an enumeration rather than a bitmask (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: Implement writer lock-stealing for better scalability (Alex Shi) [Orabug: 17237186]  
- rwsem-spinlock: Implement writer lock-stealing for better scalability (Yuanhan Liu) [Orabug: 17237186]  
- mpt3sas: update from v02.100.00.00 to v3.00.00.00 (Sreekanth Reddy) [Orabug: 17249239]  
- sched: Change position of resched_cpu() in load_balance() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Move up affinity check to mitigate useless redoing overhead (Joonsoo Kim) [Orabug: 16988083]  
- sched: Prevent to re-select dst-cpu in load_balance() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Explicitly cpu_idle_type checking in rebalance_domains() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Rename load_balance_tmpmask to load_balance_mask (Joonsoo Kim) [Orabug: 16988083]  
- sched: Don't consider other cpus in our group in case of NEWLY_IDLE (Joonsoo Kim) [Orabug: 16988083]  
- sched: Fix init NOHZ_IDLE flag (Vincent Guittot) [Orabug: 16988083]  
- sched: Fix select_idle_sibling() bouncing cow syndrome (Mike Galbraith) [Orabug: 16988083]  
- disable mlx5 compilation (Ajaykumar Hotchandani)   
- xfs: Fix the logic check for all quotas being turned off (Chandra Seetharaman)   
- xfs: return FIEMAP_EXTENT_UNKNOWN for delayed allocation extent (Jie Liu)   
- xfs: Don't keep silent if sunit/swidth can not be changed via mount (Jie Liu)   
- xfs: fix rounding in xfs_free_file_space (Dave Chinner)   
- FSX on 512 byte block size filesystems has been failing for some time with corrupted data. The fault dates back to the change in the writeback data integrity algorithm that uses a mark-and-sweep approach to avoid data writeback livelocks. (Dave Chinner)   
- xfs: don't free EFIs before the EFDs are committed (Dave Chinner)   
- xfs: Fix WARN_ON(delalloc) in xfs_vm_releasepage() (Jan Kara)   
- xfs: fix potential infinite loop in xfs_iomap_prealloc_size() (Brian Foster)   
- hxge: add support for Oracle 10Gb Ethernet adapter (James Puthukattukaran) [Orabug: 16443155]  
- rds: complete port of RDS from UEK2 (2.6.39-400.107.0.el5uek) (Venkat Venkatsubra)   
- rds: RDS files of UEK2 (2.6.39-400.107.0.el5uek) as is (Venkat Venkatsubra)   
- rds: Add rds.h file (Ajaykumar Hotchandani)   
- Enable SDP build in config file. (Ajaykumar Hotchandani)   
- remove drivers/infiniband/debug (Ajaykumar Hotchandani)   
- Removed srp_1.5.3 (Ajaykumar Hotchandani)   
- Revert "mlx4_core: use __cancel_delayed_work in IRQ context" (Ajaykumar Hotchandani)   
- sdp: fix cpu lock-up when sdp call ib_fmr_pool_map_phys (Shamir Rabinovitch)   
- sdp: IB_CQ_VECTOR_LEAST_ATTACHED will not be supported in ofed-2.0 (Shamir Rabinovitch)   
- sdp: port sdp to latest devel branch (Shamir Rabinovitch)   
- sdp: copy sdp from uek-2.0 to ofed-2.0 (Shamir Rabinovitch)   
- iser: panic on iser login/logout (Shamir Rabinovitch) [Orabug: 16313854]  
- mlx4_en: Align timestamping support with upstream kernel (Saeed Mahameed)   
- mlx4_ib: clear comp mask bit of deleted GUID entries after deletion (Saeed Mahameed)   
- ib_core: fixed resource leak in case of error (Saeed Mahameed)   
- IB: Introduce Shared PD support (Saeed Mahameed)   
- ib_core: IB providers/ULPs Relaxed (User) FMR set to NULL (Saeed Mahameed)   
- mlx4_ib: Enable usermode FMR (Saeed Mahameed)   
- ib_core: Enable usermode FMR (Saeed Mahameed)   
- rdma_cm: add ability to control the QP timeout value (Saeed Mahameed)   
- rdma_cm: adding the RDMA_CM_EVENT_ALT_PATH_LOADED event (Dotan Barak)   
- mlx4_ib: 6305 bugfix: set the counter sets of the alternate path in the QP (Dotan Barak)   
- mlx4_ib: Fix the attribute sq_sig_type value in query qp (Saeed Mahameed)   
- rdma_cm: rdma_create_qp not setting up client context correctly (Saeed Mahameed)   
- rmda_cm: add APM support to rdma_cm. (rdma_enable_apm) (Saeed Mahameed)   
- mlx5: Update CMD_IF_REV to 4 (Moshe Lazer)   
- mlx4_core: resource tracker fix error flow in add_res_range (Saeed Mahameed)   
- mlx5: Implement new intialization sequeuenc (Moshe Lazer)   
- ib/ipoib: change mode only when interface is down. (Erez Shitrit)   
- ib/ipoib: avoid pkey value 0 in child interface. (Erez Shitrit)   
- ib/ipoib: Fix index 0 pkey value in ipoib sriov env. (Erez Shitrit)   
- ib/ipoib: limit the max number of receive/transmit queues to 16 (Tal Alon)   
- mlx4_en: reuse mapped memory in RX flow (v2) (Eugenia Emantayev)   
- mlx5: Fix check of number of entries in create CQ (Eli Cohen)   
- mlx5: fix uninitialized var warning (Eli Cohen)   
- mlx5: fix send work queue size calculation (Eli Cohen)   
- ib/core: Fix cleanup of user resources (Eli Cohen)   
- mlx5_ib: fix compilation issues in ubuntu 12.4 The driver uses 2 different enum types in 'switch' and in 'if' statements. This is causing compilation warnings. This patch resolves the issues by replacing the enum with int. (Moshe Lazer)   
- eth_ipoib: fix hw update in sr-iov interfaces. (Erez Shitrit)   
- ib/ipoib: handle failure on ipoib_cm_dev_init() for init flow (Tal Alon)   
- mlx4_core: resolvs kernel panic when connectx_port_config fail to set ports (Moshe Lazer)   
- mlx5: modify mr cache sizes (Eli Cohen)   
- Update driver release date (Eli Cohen)   
- mlx5: fix manipulation of device in healt list (Eli Cohen)   
- mlx5: fix failure to load on 32 bit archs (Eli Cohen)   
- mlx5: Add DC support (Eli Cohen)   
- ib/core: Add support for DC (Eli Cohen)   
- mlx4_core: implement loopback prevention for ETH qps (Jack Morgenstein)   
- ib_umad: keep devnum of port cdev and sm_cdev until they are freed (Moshe Lazer)   
- mlx5: Use UMR based registration directly on mlx5 (Eli Cohen)   
- mlx5: allow to clear commands stats (Eli Cohen)   
- ib/ipoib: change skb memory allocation for init process from GFP_ATOMIC to GFP_KERNEL (Tal Alon)   
- net/mlx4_en: LLS statistics (Amir Vadai)   
- net/mlx4_en: Add Low Latency Socket (LLS) support (Amir Vadai)   
- mlx4_core: Free memory only if UNMAP succeeded. (Majd Dibbiny)   
- eth_ipoib: fix bug in add new vif. (Erez Shitrit)   
- eth_ipoib: remove unneeded tag (Erez Shitrit)   
- IB/mlx4: Fetch XRC SRQ in the CQ polling code (Shlomo Pongratz)   
- mlx4_core: Implement SRQ object lookup from srqn (Shlomo Pongratz)   
- IB/core: Verify that QP handler is valid before dispatching events (Shlomo Pongratz)   
- net/mlx4: Add sysFS for vf link state support (Rony Efraim)   
- net/mlx4: Add vf link state support (Rony Efraim)   
- Revert "mlx4_en: reuse mapped memory in RX flow" (Vladimir Sokolovsky)   
- mlx5: improve mr caches (Eli Cohen)   
- mlx4_core: Dynamic VST to VST vlan/qos changes (Jack Morgenstein)   
- mlx4_en: reuse mapped memory in RX flow (Eugenia Emantayev)   
- mlx4: add pci domain to module params that use bdf-to-value format (Moshe Lazer)   
- mlx5: Add support to measure average command time (Eli Cohen)   
- ib/core: add means to measure average time of a command (Eli Cohen)   
- net/mlx4_core eSwitch - add support VST with priority tag+ remove debug prints (Rony Efraim)   
- mlx4_en: Use state_lock to protect ethtool rules database (Hadar Hen Zion)   
- IB/core: Remove DMFS rules from uobject rule_list when ib_destroy_flow() fails (Hadar Hen Zion)   
- IB/core: Do not access flow_id after destroy_flow() is called (Hadar Hen Zion)   
- mlx4_ib: Free mailbox after create flow is done (Hadar Hen Zion)   
- mlx4_ib: Check index before access the array in create/destroy flow (Hadar Hen Zion)   
- mlx4_core : implemented a function ib_rate_to_mlx4 that checks if the 	    static_rate is a valid value before assigning it to the 	    ah_attr in mlx4_set_path. (majd@mellanox.com)   
- mlx4: add means to measure command execution time (Eli Cohen)   
- mlx5: Add health plugin support (Eli Cohen)   
- mlx4_en: fix skb leakage (Eugenia Emantayev)   
- ib/ipoib: add call to dev_set_mtu when setting mode to connect (Tal Alon)   
- ib/ipoib: update broadcast record according to the new bcast from the sm. (Erez Shitrit)   
- ib/ipoib: fix hard_header return value (Erez Shitrit)   
- Fix broken previous commit (Eli Cohen)   
- mlx5: fix query of max rd atomic (Eli Cohen)   
- mlx5: Fix offsets in query hca cap (Eli Cohen)   
- mlx5: Add descriptive strings to health bufer reports (Eli Cohen)   
- mlx5: Add fast registraton support (Eli Cohen)   
- eth_ipoib: fix neigh hash in each slave (Erez Shitrit)   
- ib/ipoib: add parameters range description to driver info validates received parameters (Tal Alon)   
- mlx5: Fix fast path configuration (Eli Cohen)   
- ib_core: xrc cleanup (Yishai Hadas)   
- kernel-uek.spec: Remove pesign >= 0.10-4 as build requirement (Ajaykumar Hotchandani)   
- config file change (Ajaykumar Hotchandani)   
- Kconfig and Makefile specific changes (Ajaykumar Hotchandani)   
- mlx4_vnic: Fix reference path to hw/mlx4 header files (Ajaykumar Hotchandani)   
- mlx4: Fix compilation error for mlx4_get_vf_config (Ajaykumar Hotchandani)   
- Fix IPoIB compilation issue. (Ajaykumar Hotchandani)   
- mlx5: remove __dev* attributes (Ajaykumar Hotchandani)   
- mlx4_core: remove __dev* attributes (Bill Pemberton)   
- IB/srp: Fail I/O requests if the transport is offline (Bart Van Assche)   
- IB/srp: Avoid endless SCSI error handling loop (Bart Van Assche)   
- IB/srp: Avoid sending a task management function needlessly (Bart Van Assche)   
- IB/srp: Track connection state properly (Bart Van Assche)   
- IB/srp: send disconnect request without waiting for CM timewait exit (Vu Pham)   
- IB/srp: destroy and recreate QP and CQs when reconnecting (Ishai Rabinovitz)   
- IB/srp: Eliminate state SRP_TARGET_DEAD (Bart Van Assche)   
- IB/srp: Allow SRP disconnect through sysfs (Bart Van Assche)   
- IB/srp: Suppress superfluous error messages (Bart Van Assche)   
- IB/srp: Introduce the helper function srp_remove_target() (Bart Van Assche)   
- IB/srp: Process all error completions (Bart Van Assche)   
- IB/srp: Introduce srp_handle_qp_err() (Bart Van Assche)   
- IB/srp: Simplify SCSI error handling (Bart Van Assche)   
- IB/srp: Keep processing commands during host removal (Bart Van Assche)   
- IB/srp: Eliminate state SRP_TARGET_CONNECTING (Bart Van Assche)   
- IB/srp: Increase block layer timeout (Bart Van Assche)   
- net/mlx4_core: Disallow releasing QPs before steering rules are detached (Hadar Hen Zion)   
- mlx4_core: Fix error flow in the flow steering wrapper (Hadar Hen Zion)   
- mlx4_core: Fix potential deadlock in mlx4_eq_int() (Jack Morgenstein)   
- mlx4_core: Add QPN enforcement for flow steering rules set by VFs (Hadar Hen Zion)   
- Revert "net/mlx4_core: Disallow releasing QPs before steering rules are detached" (Ajaykumar Hotchandani)   
- mlx4_en: update driver version to 2.1.3 (Eugenia Emantayev)   
- mlx4_core: Fix advertisement of wrong PF context behaviour (Or Gerlitz)   
- net/mlx4_en: Use generic etherdevice.h functions. (Yan Burman)   
- net/mlx4_en: Can set maxrate only for TC0 (Amir Vadai)   
- IB/mlx4: Fix spinlock order to avoid lockdep warnings (Jack Morgenstein)   
- Revert "mlx4_en: fix QoS in old kernels" (Ajaykumar Hotchandani)   
- mlx4_core: use __cancel_delayed_work in IRQ context (Saeed Mahameed)   
- eth_ipoib:  use hash for managing the neighs in each slave. (Erez Shitrit)   
- IB/iser: fix device removal flow (Roi Dayan)   
- Fix compliation issue on 32 bit systems (Eli Cohen)   
- mlx5: move UMR completions to event driven (Eli Cohen)   
- eth_ipoib: add bh lock in order to avoid soft-lockups (Erez Shitrit)   
- mlx4_vnic: align with OFED2 upstream 3.7 kernel (Saeed Mahameed)   
- mlx4_vnic: adapt vnic to ofed2 mlx4 implementation (Saeed Mahameed)   
- mlx4_vnic: add mlx4_vnic (Saeed Mahameed)   
- ib/ipoib: add sysfs for tss/rss over child interface (Saeed Mahameed)   
- ib/ipoib: fix memory leak in error flow (Saeed Mahameed)   
- mlx4_ib: Fix connection of UD QPs in rdmacm for SRIOV/RoCE (Shani Michaelli)   
- mlx4_core: fix error introduced in a merge from upstream (Jack Morgenstein)   
- Fix compliation issue on 32 bit systems (Eli Cohen)   
- mlx4_en: fix statistics view in SRIOV mode (Eugenia Emantayev)   
- mlx5: change SRQ limit event msg to debug (Eli Cohen)   
- mlx5: dump selected error CQEs (Eli Cohen)   
- mlx5: move UMR completions to event driven (Eli Cohen)   
- mlx4_core: Avoid setting ports for auto when only one port type is supported (Moshe Lazer)   
- mlx4_core: cleared the mailbox->buf (memset 0) before using it.            mlx4_set_port_general_context struct is smaller than the mailbox->buf            therefore clearing only it was not enough and we had to clear the whole            mailbox->buf in order to ensure garbage-free buffer. (majd@mellanox.com)   
- mlx4_en: setting number of rings resulted in deadlock (Matan Barak)   
- mlx5: fix query of max rdma/atomics (Eli Cohen)   
- mlx4_en: update driver version to 2.1.2 (Eugenia Emantayev)   
- mlx4_en: update driver version to 2.1.1 (Eugenia Emantayev)   
- IB/iser: Fix coverity errors (Roi Dayan)   
- mlx5: update modinfo string for mlx5_ib (Eli Cohen)   
- ib/ipoib: fix panic at cm tx creation. (Erez Shitrit)   
- mlx5: fix opt param mlx5 translation table (Eli Cohen)   
- mlx4_core: sysfs, fix usage of log_num_mtt module parameter (Yishai Hadas)   
- ib/ipoib: in additional to commit 2bf6943f4f9ea9f1f69b4ef5acb4ece11bf50bc0 (Erez Shitrit)   
- mlx5: fix opt parameters usage (Eli Cohen)   
- ib/ipoib: fix kernel panic after mode changing. (Erez Shitrit)   
- mlx5: add missing spare EQEs in create EQ (Eli Cohen)   
- Revert "ib/ipoib: enhance interop between TSS device to non-TSS device." (Erez Shitrit)   
- mlx5: mark mlx5_ib QPs how they were created (Eli Cohen)   
- mlx5: Fix alignement of data buffers for umr registration (Eli Cohen)   
- ib/ipoib: fix for missing ping reply issue. (Erez Shitrit)   
- ib/ipoib: Call skb_dst_drop() once skb is enqueued for sending (Erez Shitrit)   
- net/mlx4_core : update enforce QP param in VST (Rony Efraim)   
- net/mlx4_core: Always use __mlx4_un/register_vlan for VST (Rony Efraim)   
- mlx4_ib: set link type for the primary path (Eli Cohen)   
- mlx4_core: Fix mem leak in SRIOV mlx4_init_one error flow (Jack Morgenstein)   
- mlx4_core: Add wrapper for mlx4_DIAG_RPRT command to return BAD_OP (Jack Morgenstein)   
- mlx4_en: do not allow certain ethtool options when alloc resources failed (Eugenia Emantayev)   
- mlx4_en: restore ring inflight atomic variable (Eugenia Emantayev)   
- ib/ipoib: move (one more) message to be at debug level instead of warn (Erez Shitrit)   
- ib/ipoib: move message to be at debug level instead of warn (Erez Shitrit)   
- mlx5: change message from warn to debug (Eli Cohen)   
- mlx4_en: No_wqes counter should only be reported via Ethtool (Yevgeny Petrilin)   
- mlx4_en: inline threshold must be unsigned (Eugenia Emantayev)   
- mlx4_en: make receive flow more readable (Eugenia Emantayev)   
- ib/ipoib: fix skb true size (Erez Shitrit)   
- mlx5: fix offset to health buffer (Eli Cohen)   
- mlx4_en: fix kernel panic on XenServer hypervisor (Eugenia Emantayev)   
- mlx4_core: Ignore bf flag in mlx4_qp_reserve_range when count is too large (Jack Morgenstein)   
- mlx4_core: use kernel to allocate and release umad cdevs (Moshe Lazer)   
- mlx4_ib: used uninitialized compilation warning (Moshe Lazer)   
- mlx4_en: change driver version to 2.1 and add date (Eugenia Emantayev)   
- mlx4_en: remove TX shifting (Eugenia Emantayev)   
- memtrack: handle umem put page (Yishai Hadas)   
- mlx4_en: fix wrong MAC address (Eugenia Emantayev)   
- ib_srp: update module version to 1.2 (Alex Tabachnik)   
- mlx4_core: fix ib_uverbs_get_context flow (Yishai Hadas)   
- IB/core: Fix memory leaks in ib_uverbs_create_flow (Hadar Hen Zion)   
- mlx4_core: Fix Coverity issue (Hadar Hen Zion)   
- IB/core: Fix Coverity issue (Hadar Hen Zion)   
- ib/ipoib: remove compilation warning (Erez Shitrit)   
- mlx4_en: get timestamp request from correct packet info (Eugenia Emantayev)   
- mlx4_en: make alignment generic (Eugenia Emantayev)   
- Revert "DEBUG PATCH" (Moshe Lazer)   
- Revert "DEBUG PATCH update" (Moshe Lazer)   
- ib/ipoib: allocate always one linear buffer at the RX flow (Erez Shitrit)   
- ib/ipoib: enhance interop between TSS device to non-TSS device. (Erez Shitrit)   
- mlx4_en: fix DCB_ENABLE flag (Eugenia Emantayev)   
- IB/iser: Move important debug prints to debug level 1 (Roi Dayan)   
- mlx4_en: add check for DMA mapping error (Eugenia Emantayev)   
- mlx4_en: align dma to 64 (Eugenia Emantayev)   
- ib_mad: Avoid looking into mad struct before finding it in list (Moshe Lazer)   
- net/mlx4_core: Translate guest B0 steering rules to DMFS (Hadar Hen Zion)   
- net/mlx4_core: Add helper function to translate B0 steering to DMFS (Hadar Hen Zion)   
- net/mlx4_core: Disallow releasing QPs before steering rules are detached (Hadar Hen Zion)   
- net/mlx4_core: Use 64 bit resource ID when doing lookup (Hadar Hen Zion)   
- net/mlx4_en: Remove ethtool flow steering rules before releasing QPs (Hadar Hen Zion)   
- ib_uverbs: added ref_cnt to sysfs (Marcel Apfelbaum)   
- ib/ipoib: disable reinit at the middle of driver down. (Erez Shitrit)   
- mlx4_core: change warn msg to dbg msg (Moshe Lazer)   
- mlx4_core: Fix Coverity issues. (Hadar Hen Zion)   
- IB/mlx4: Fix Coverity issues (Hadar Hen Zion)   
- IB/core: Fix Coverity issues (Hadar Hen Zion)   
- mlx4_en, mlx4_ib: show VSD string through sysfs (Hadar Hen Zion)   
- mlx4_core: Enhance flow steering validation checks (Hadar Hen Zion)   
- IB/mlx4: use ARRAY_SIZE kernel macro (Hadar Hen Zion)   
- net/mlx4_core: Fix wrong order of flow steering resources removal (Hadar Hen Zion)   
- mlx4_core: map eq inconsistency with prm (Moshe Lazer)   
- net/mlx4_core: Preparation + workaround for the UPDATE_QP FW cmd (Rony Efraim)   
- mlx4_ib: assign all dev numbers in low-level driver when dev_assign_str param is active (Jack Morgenstein)   
- mlx4_core: fix the method to get phys func from its virt func (Moshe Lazer)   
- ib_iser: move some error prints to debug prints (Roi Dayan)   
- ib_iser Fix kernel crash on ib_iser module unload immediately after initiator logout (Alex Tabachnik)   
- ib_srp: simplifying handle port down, cm dreq, scsi error recovery (Alex Tabachnik)   
- ib_srp: check for error return to avoid garbage gid in initiator_id (Alex Tabachnik)   
- ib_srp: bail out when scsi command in req is NULL (Alex Tabachnik)   
- mlx4: Allow RAW PACKET QPs on mlx4 (Eli Cohen)   
- ib/ipoib: fix for ib_unregister_event_handler (Erez Shitrit)   
- mlx4_en: fix memory leak in mlx4_en_activate_rx_rings (Eugenia Emantayev)   
- mlx4_en: verify mlx4_en module parameters (Eugenia Emantayev)   
- mlx4_en: change ethtool specifications for 1G, 10G, 40G support in advertising and supported fields (Rana Shahout)   
- IB/core: Fix raw Ethernet qp bug (Hadar Hen Zion)   
- IB/core: add module parameter check to allow a non-root user to attach DMFS rules (Hadar Hen Zion)   
- IB/mlx4: Add support for Flow Steering (Hadar Hen Zion)   
- IB/core: Export ib_create/destroy_flow through uverbs (Hadar Hen Zion)   
- IB/core: Implement ib_create/destroy_flow (Hadar Hen Zion)   
- net/mlx4_core: Add flow steering support to be used by mlx4_ib (Hadar Hen Zion)   
- mlx4_core: Directly expose fields of HW flow steering rule control segment (Hadar Hen Zion)   
- mlx4_core: Replace flow steering fields names to match the PRM (Hadar Hen Zion)   
- mlx4_core: Expose flow steering HW structs to be used by mlx4_ib module (Hadar Hen Zion)   
- mlx4_ib: Remove attach/detach flow API implementation (Hadar Hen Zion)   
- ib_uverbs: Remove ib_uverbs_attach/detach_flow leftovers (Hadar Hen Zion)   
- Revert "ib_core: Implement ib_attach_flow ib_detach_flow" (Hadar Hen Zion)   
- Revert "mlx4_ib: Add support for ib_attach_flow and ib_detach_flow." (Hadar Hen Zion)   
- Revert "ib_uverbs: Export ib_attach_flow and ib_detach_flow to userspace." (Hadar Hen Zion)   
- Revert "rdma_cm: Implement rdma_get_l2" (Hadar Hen Zion)   
- mlx4_en: add port state test before operate mlx4_en_set_cq_moder in mlx4_en_set_ringparam function. (Rana Shahout)   
- mlx4_en: avoid loosing statistics (Eugenia Emantayev)   
- ib_iser: add module version (Roi Dayan)   
- mlx5: fix health counter read (Eli Cohen)   
- mlx4_en: set correct MTU in SRIOV (Eugenia Emantayev)   
- Release Date is updated to __DATE__ instead of a static string (Alex Markuze)   
- mlx4_core: use msi_x module param to limit num of MSI-X irqs (Moshe Lazer)   
- Seting ring size to default when module param set incorrectly (Alex Markuze)   
- eth_ipoib: move task from rx flow to workqueue (Erez Shitrit)   
- mlx5: fix health polling race (Eli Cohen)   
- DEBUG PATCH update To provide more info on kernel panic in mad layer. (Moshe Lazer)   
- memtrack: add tracking for kfree_rcu (Eugenia Emantayev)   
- mlx4_en: Set number of rx/tx channels using ethtool (Amir Vadai)   
- mlx4_en: fix incorrect timestamp (Eugenia Emantayev)   
- mlx4_en: remove explicit call to skb_reset_mac_header (Eugenia Emantayev)   
- ib/ipoib: move global client_data_lock spin_lock init to module_init (Erez Shitrit)   
- mlx5: use MPI profile as default (Eli Cohen)   
- ib/ipoib: protect client data with spin-lock. (Erez Shitrit)   
- ib/ipoib: disable lro over pv interface. (Erez Shitrit)   
- eth_ipoib: change lock over bh, use regular lock. (Erez Shitrit)   
- mlx4_core: CQE/EQE by default is 64B (Yishai Hadas)   
- mlx5: change fw health polling to new definition (Eli Cohen)   
- mlx5: fix missing symbols in 32 bit platforms (Eli Cohen)   
- mlx5: use separate EQ of command interface (Eli Cohen)   
- mlx5: change scatter to cqe to new PRM (Eli Cohen)   
- net/mlx4: Update FW DEV CAP bits of VST and FSM (Yan Burman)   
- net/mlx4: Add support to get VF config (Yan Burman)   
- net/mlx4: Fix the VF numbering from 0 (instead of 1) (Yan Burman)   
- mlx4_en: fix no vlan traffic on vlan interface (Eugenia Emantayev)   
- DEBUG PATCH To provide info on kernel panic in mad layer. (Moshe Lazer)   
- mlx5: fix warning on out of array bounds (Eli Cohen)   
- mlx5: DEBUG PATCH (Eli Cohen)   
- mlx4_en: reset mac_header (Eugenia Emantayev)   
- mlx4_core: fix counters leak as part of slave down (Yishai Hadas)   
- mlx4_ib, ib_core: UP setting for Raw Eth QP (Amir Vadai)   
- mlx4_en: help disperse interrupts workload in TX flow (Eugenia Emantayev)   
- mlx4_en: help disperse interrupts workload in RX flow (Eugenia Emantayev)   
- mlx4_en: optimize inline logic in TX flow (Eugenia Emantayev)   
- mlx4_en: remove atomic from transmit flow (Eugenia Emantayev)   
- mlx4_en: use unlikely when checking for bounce in en_xmit (Eugenia Emantayev)   
- mlx4_en: code cleanup (Eugenia Emantayev)   
- Issue: 170150 mlx4: Allow to set CQ Ignore Overrun under capability check (Igor Ivanov)   
- Issue: 170150 IB/mlx4: Add Cross-channel functionality (Igor Ivanov)   
- Issue: 170150 IB/core: Add ib_uverbs_modify_cq_ex (Igor Ivanov)   
- Issue: 170150 IB/core: Add ib_uverbs_create_qp_ex (Igor Ivanov)   
- Issue: 170150 IB/core: Add Infrastructure to support verbs extensions through uverbs (Igor Ivanov)   
- Issue: 170150 IB/core: Add support for Cross Channel operations (Igor Ivanov)   
- Issue: 170150 IB/mlx5: Change CQ modify to have attributes/mask and flags param (Igor Ivanov)   
- Issue: 170150 IB: Change CQ modify to have attributes/mask and flags param (Igor Ivanov)   
- ib/core: change error prints in cm module to debug prints. (Jack Morgenstein)   
- mlx4: bf_qp parameter added to mlx4_qp_reserve_range should be a flags param. (Jack Morgenstein)   
- mlx4_en: use linear skbs in receive flow (Eugenia Emantayev)   
- mlx5: debug patch - freeze on too long completions (Eli Cohen)   
- mlx5: debug patch for umr problem (Eli Cohen)   
- mlx4_core: Add support for different value formats in BDF-Val params (Moshe Lazer)   
- mlx4_core: Add more info to mlx4_cmd_post failure error messages (Jack Morgenstein)   
- mlx4_en: ignore init and shutdown hypervisor events (Eugenia Emantayev)   
- mlx5: fix false compilation error in qp.c (Eli Cohen)   
- Fix format specifier for printk (Eli Cohen)   
- mlx4_ib: in SRIOV, should not reserve QP range for IPoIB use when DMFS is enabled. (Jack Morgenstein)   
- mlx4_core: use symbolic name for FW commands in warnings (Jack Morgenstein)   
- mlx5: fix race in destroy CQ (Eli Cohen)   
- mlx5: fix error flow in destroy SRQ (Eli Cohen)   
- mlx4_core: Support setting a different port_type_array for each HCA (Moshe Lazer)   
- mlx4_en: use div_u64 for division (Eugenia Emantayev)   
- mlx4_core: disable mlx4_QP_ATTACH calls from guests if master is doing flow steering. (Jack Morgenstein)   
- Adding parametre validation to ipoib_printk (Alex Markuze)   
- eth_ipoib: enable GRO on the pv interface (Erez Shitrit)   
- mlx4_en: release QP when destroying TX ring (Eugenia Emantayev)   
- mlx5: add profie selection of mr cache sizes (Eli Cohen)   
- memtrack: fix broken memtrack on vzalloc (Eli Cohen)   
- Add mlx5 driver support (Eli Cohen)   
- ib/core: add UMR support for verbs (Eli Cohen)   
- ib/core: Add means to measure command execution times (Eli Cohen)   
- mlx4_core: Don't fail reg/unreg vlan for upstream guests to 3.8 (Jack Morgenstein)   
- mlx4_core: Turn off device-managed FS bit in dev-cap wrapper if DMFS is not enabled (Jack Morgenstein)   
- mlx4_core: change resource quotas to enable supporting upstream-kernel guests (Jack Morgenstein)   
- mlx4_core: Support setting a different num_vfs and probe_vf for each HCA (Moshe Lazer)   
- ib/ipoib: fix ipoib_neigh index calculation (Shlomo Pongratz)   
- mlx4_en: split outgoing traffic to two different rings (Eugenia Emantayev)   
- Flsu WQ should come after flush_paths in CM mode (Alex Markuze)   
- net/mlx4_en: Synchronize unicast MAC filter implementation with upstream (Yan Burman)   
- ib/iser: add BullseyeCoverage pragma lines around ilog2 calls (Roi Dayan)   
- ib_srp: fix oops during module unload on OEL 6.2 (Alex Tabachnik)   
- Moved the tx ethtoll counters to ipoib_send (Alex Markuze)   
- ib/ipoib: fix deadlock between dev_change_flags to __ipoib_dev_flush (Erez Shitrit)   
- Adding flush WQ for ipoib_ib_dev_cleanup to avoid cm_create_tx_qp handling bad pointers Issue: 111256, 168923 (Alex Markuze)   
- mlx4: change QP allocation scheme (Eugenia Emantayev)   
- ib/ipoib: avoid loading the kernel when rtnl is locked. (Erez Shitrit)   
- ib/ipoib: fix deadlock between ipoib_mcast_dev_flush to ipoib_mcast_join_finish (Erez Shitrit)   
- mlx4_ib: use correct device for XRC (Yishai Hadas)   
- net/mlx4_en: Fix resource leak on module unload (Yan Burman)   
- net/mlx4_en: Fix race in set_mac_address regression (Yan Burman)   
- ib/ipoib: fix panic on ipoib_get_stats (Erez Shitrit)   
- mlx4_core: device revision support (Yishai Hadas)   
- mlx4_core: print more info when command times out (Jack Morgenstein)   
- ib/ipoib: Fix ipoib_neigh hashing to use the correct daddr octets (Shlomo Pongratz)   
- ib/ipoib: : Fix race condition in neigh creation under MQ (Shlomo Pongratz)   
- ib/ipoib: rtnl_unlock cannot come after free_netdev (Erez Shitrit)   
- ib/ipoib: fix deadlock over vlan_mutex. (Erez Shitrit)   
- 	This is a partial fix for bad flow when ipoib_reinit fails to ipoib_dev_init. 	This fix enables the driver to call ib_unregister_event_handler in ipoib_remove_one, without crushing, 	though ib_register_event_handler was not called. (Alex Markuze)   
- eth_ipoib: fix compilation over xen-server. (Erez Shitrit)   
- ib/ipoib: remove netlink code till further support. (Erez Shitrit)   
- mlx4_core: move out label to the right place (Eugenia Emantayev)   
- IB/mlx4: Do reg/unreg vlan for RoCE (Jack Morgenstein)   
- {IB,EN}/mlx4: In RoCE allow guests to have multiple GIDS (Jack Morgenstein)   
- IB/mlx4: prepare update_gids flow for multiple gids (Jack Morgenstein)   
- mlx4_en: add check for QoS capability bit (Eugenia Emantayev)   
- EN/mlx4: use vlan id in mlx4_unregister_vlan instead of vlan index (Jack Morgenstein)   
- mlx4_core: fix reg/unreg vlan and reg/unreg mac to conform to the PRM (Jack Morgenstein)   
- memtrack: alloc/free pages handle size inconsistency (Yishai Hadas)   
- mlx4_en: use num_possible_cpus instead of num_default_rss_queues (Eugenia Emantayev)   
- mlx4_en: memory leak in loading driver (Matan Barak)   
- net/mlx4_en: Add support for destination MAC in steering rules (Yan Burman)   
- net/mlx4_en: Implement fdb ndo_fdb_{add,del,dump} (Yan Burman)   
- net/mlx4_en: Add unicast MAC filtering (Yan Burman)   
- net/mlx4_en: Manage hash of MAC addresses per port (Yan Burman)   
- net/mlx4_en: Save old MAC address of the port so we can replace it later (Yan Burman)   
- net/mlx4_en: Re-arrange ndo_set_rx_mode related code (Yan Burman)   
- net/mlx4: Move ethernet related functionality to mlx4_en out of mlx4_core (Yan Burman)   
- net/mlx4_en: Cleanup multiline strings (Yan Burman)   
- net/mlx4_en: Optimize loopback related checks in data path (Yan Burman)   
- net/mlx4_core: Set number of msix vectors under SRIOV mode to firmware defaults (Or Gerlitz)   
- ib/ipoib: fix possible deadlock on pkey_poll task. (Erez Shitrit)   
- mlx4_en: fix BlueFlame race (Eugenia Emantayev)   
- ib_mad: Add SA MADs congestion control (Moshe Lazer)   
- ib/ipoib: add robust to ipoib_mcast_join_finish (Erez Shitrit)   
- ib/ipoib: fix deadlock between ipoib_mcast_dev_flush and ipoib_mcast_join_finish (Erez Shitrit)   
- IB/iser: Enable iser to work when FMRs are not supported (Or Gerlitz)   
- mlx4_en: ethtool should return error on turning on autoneg (Matan Barak)   
- IB/mlx4: deprecate "failed to alloc bf reg" message from err to debug (Jack Morgenstein)   
- mlx4_en: fix bad english in modprobe and ethtool (Amir Vadai)   
- mlx4_en: Move initalizations to beginning of init_netdev (Amir Vadai)   
- mlx4_en: pad ethernet packets smaller than 17 bytes (Amir Vadai)   
- mlx4_en: print error message on cqe error (Amir Vadai)   
- mlx4_en: fix set port ratelimit. (Sagi Grimberg)   
- mlx4_en: fix MLX4_RATELIMIT_DEFAULT define include (Sagi Grimberg)   
- mlx4_en: report number of rings in RSS as a power of 2 (Amir Vadai)   
- mlx4_en: fix UP limit in ieee_ets->prio_tc (Amir Vadai)   
- mlx4_core: Do not allow mlx4_bitmap_init to reserve more slots than available (Amir Vadai)   
- mlx4_en: fix open-lldp DCB support (Sagi Grimberg)   
- remove dead code - mlx4_en_can_lro (Sagi Grimberg)   
- mlx4_en: add support for debugfs (Shani Michaelli)   
- mlx4_en: TX ring size default to 1024 (Yevgeny Petrilin)   
- ib/ipoib: Fix deadlock between rmmod and set_mode (Erez Shitrit)   
- ib/ipoib: fine tune commit aee8f48642fb83820463d042ca80fd5372947cb5 (Erez Shitrit)   
- In 4K mtu Rx, adding 128 bytes to linear part (Alex Markuze)   
- ib/ipoib: getout whenever failed to load port. (Erez Shitrit)   
- ib_ipoib: Fixing issue with delayed work running after child is killed. (Erez Shitrit)   
- mlx4_en: extract changes to compat from backport (Amir Vadai)   
- IB/mlx4: in RoCE, report network-view of number of GIDS in query_port. (Jack Morgenstein)   
- srp: Create additioal tree with srp code from mofed 1.5.3, separated to two parts one for all the distributions and one for sles11sp2 and kernels bigger then 3.0. Original srp code remaine as is and when will be needed will be used for developement (Alex Tabachnik)   
- mlx4_en: fix QoS in old kernels (Amir Vadai)   
- ib_core: contig allocation use NOWARN flag (Yishai Hadas)   
- ib_core: fix memory leak in contig error flow (Yishai Hadas)   
- mlx4_core: Fixed IPoIB flow steering (Hadar Hen Zion)   
- ib/ipoib: Add print log for debug. (Erez Shitrit)   
- ib/ipoib: Fix mess in the select queue in TSS flow. (Erez Shitrit)   
- ipoib: fix mcast dead-lock (Yishai Hadas)   
- Fixing RHL6.2 memtrack backports for alloc_worqueue (Alex Markuze)   
- mlx4_core: additional fix for qp_detach_common (Eugenia Emantayev)   
- mlx4_core: fix broken logic when removing promisc qp (Eugenia Emantayev)   
- ib/ipoib: doesn't allow num of tx channel to be 2. (Erez Shitrit)   
- net/eipoib: sys/fs show of "served" should give the new member as it does with the valid members (Erez Shitrit)   
- mlx4_en: counters init to non-index (Yishai Hadas)   
- mlx4_core: Do not guarantee counter availability in SRIOV (Jack Morgenstein)   
- mlx4_en: counters fine-tuned (Yishai Hadas)   
- mlx4_core: max counters support (Yishai Hadas)   
- mlx4_core: change code to endian safe (Hadar Hen Zion)   
- mlx4_ib: allow FS rules attachments with missing headers (Hadar Hen Zion)   
- mlx4_en/mlx4_ib: move BE_SHORT/WORD_MASK macro from private to common place (Hadar Hen Zion)   
- mlx4_core: configure flow steering hash to L4 mode (Hadar Hen Zion)   
- mlx4_en: Fixed ethtool rules leftovers after mlx4_en unload (Hadar Hen Zion)   
- mlx4_en: block insertion of FS ethtool rules while port is down (Hadar Hen Zion)   
- mlx4_en: Remove FS promisc rules removal from mlx4_en_start_port (Hadar Hen Zion)   
- mlx4_en: fix ethtool vlan range validation (Hadar Hen Zion)   
- mlx4_ib: Add VLAN support to RawEth QP flow steering (Hadar Hen Zion)   
- mlx4_en: fixed ip/tcp/udp multicast mac rules when inserted via ethtool (Hadar Hen Zion)   
- mlx4_en: counters moderation support (Yishai Hadas)   
- memtrack: add missing untrackable functions for EN under RH6.3 (Yishai Hadas)   
- mlx4_core: Resource wrapper for reg/unreg vlans (Jack Morgenstein)   
- mlx4_core: fix register/unreg vlan flow (Jack Morgenstein)   
- mlx4_core: fix call to __mlx4_unregister_mac (Jack Morgenstein)   
- mlx4_core: Implement resource quota enforcement when allocating various resources (Jack Morgenstein)   
- {IB,EN}/mlx4: structures and init/teardown for VF resource quotas (Jack Morgenstein)   
- memtrack: fix report (Yishai Hadas)   
- net/mlx4: Add support for MAC spoof checking (Rony Efraim)   
- net/mlx4: Add support to set default vlan id and priority for VF NIC (Rony Efraim)   
- net/mlx4: Add support the set mac address for VF NIC (Rony Efraim)   
- {IB,EN}/mlx4: Replace mlx4_en_mac_to_u64() with mlx4_mac_to_u64() (Rony Efraim)   
- net/mlx4: Add admin and oper DB (Rony Efraim)   
- mlx4_en: fix some dead-locks as of flow steering mode (Yishai Hadas)   
- mlx4_en: Do not query ethernet stats when a device port is down. (Jack Morgenstein)   
- extended counters use correct reserved bytes (Yishai Hadas)   
- mlx4_core: fix endianness bug in set_param_l (Jack Morgenstein)   
- ib/ipoib: fix the failure to delete  clone child interface. (Erez Shitrit)   
- net/mlx4_core: Fix racy flow in the driver CQ completion handler (Jack Morgenstein)   
- net/eipoib: Support bonding (active-passive mode) for eIPoIB driver. (Erez Shitrit)   
- ib/ipoib: Changes in ipoib in order to support the latest version of eIPoIB. (Erez Shitrit)   
- net/eipoib: Add ethtool file support (Erez Shitrit)   
- net/eipoib: Add sysfs support (Erez Shitrit)   
- net/eipoib: Add main driver functionality (Erez Shitrit)   
- net/eipoib: Add private header file (Erez Shitrit)   
- mlx4_en: report extra rx counters for SRIOV (Yishai Hadas)   
- mlx4_ib: add extended counters support (Yishai Hadas)   
- mlx4_en: support extended counters (Yishai Hadas)   
- mlx4_core: set device to use extended counters (Yishai Hadas)   
- fix NULL pointer assignment in the disconnection flow (Alex Tabachnik)   
- mlx4_ib: mlx4_set_path() wrote the port number into the MAC address field under RoCE (Jack Morgenstein)   
- mlx4_ib: Called rdma_port_get_link_layer with wrong port number. (Jack Morgenstein)   
- add support for CQ moderation (Alex Tabachnik)   
- mlx4_en: fix IPv6 traffic (Eugenia Emantayev)   
- ipoib: move set_skb_oob_cb_data body to ipoib.h (Vladimir Sokolovsky)   
- ib/ipoib: Fix deadlock at the release of child_interfaces. (Erez Shitrit)   
- mlx4: verify port number in __mlx4_unregister_mac (Eli Cohen)   
- ipoib: improve poll mechanism for better performance (Yishai Hadas)   
- ipoib: Replace write_lock with rw semaphore (Jack Morgenstein)   
- mlx4_core: Do not enable flow steering by default (Jack Morgenstein)   
- mlx4_core: Adjustments to Flow Steering activation logic for SRIOV (Jack Morgenstein)   
- ipoib: adapt code to netlink changes (Yishai Hadas)   
- ib/ipoib: debug prints instead of warn in tx_wc function (Erez Shitrit)   
- ib/ipoib: fix possible race between  ipoib_cm_skb_too_long call to skb free. (Erez Shitrit)   
- ib/ipoib: Fix race in the TX flow at CM mode. (Erez Shitrit)   
- ib/ipoib: change list_del to list_del_init in the tx object. (Erez Shitrit)   
- ib/ipoib: repalce list_del of the neigh->list with  list_del_init (Erez Shitrit)   
- ib/ipoib: add detailed error message on  dev_queue_xmit (Erez Shitrit)   
- ib/ipoib: adding completion to ipoib_mc (Erez Shitrit)   
- ib/ipoib: start mcast_join process only on port active. (Erez Shitrit)   
- ib/ipoib: Move QP to ERROR only when the QP is not at REST state (Erez Shitrit)   
- ib_ipoib: always mark QP as NETIF_QP (Amir Vadai)   
- ib/ipoib: fix ipoib lock is not freed issue (Shlomo Pongratz)   
- ipoib: fix a deadlock at "carrier on task" (Yishai Hadasa)   
- ib/ipoib: fix kernel panic when restarting with vma  flag (Shlomo Pongratz)   
- ib/ipoib: force cleaning of ah's in driver unloading (Erez Shitrit)   
- IB/ipoib: Remove datagram mode check for ipoib flow steering (Hadar Hen Zion)   
- ipoib: adaptive moderation fine tuned (Yishai Hadas)   
- ib/ipoib: fix access to stale cm rx context (Shlomo Pongratz)   
- ib/ipoib: Change the comparison of tx_outstanding and the timeout function. (Yishai Hadas)   
- ipoib/ib: don't release resources if the add_one failed (Dotan Barak)   
- ib/ipoib: Fix removing call for update_pmtu from  spin-lock context. (Erez Shitrit)   
- ipoib: start_xmit - RSS/TSS adaptations (Yishai Hadas)   
- ib/ipoib: attach multicast address after RSS/TSS qp num change. (Shlomo Pongratz)   
- ipoib: flow steering with TSS/RSS support (Hadar Hen Zion)   
- ipoib: adaptive moderation adaptations to RSS (Yishai Hadas)   
- ib/ipoib: Added adaptive moderation algorithm for  better latency. (Yishai Hadas)   
- ipoib: arp snooping for gid cache sync. (Erez Shitrit)   
- ipoib: add inline/blue flame support (Yishai Hadas)   
- IB/IPoIB: fix cm tx path index and strenght locking (Shlomo Pongratz)   
- ipoib: fixed NULL dereferencing in case of error flow (Dotan Barak)   
- IB/ipoib: add support for ethtool set/get_channels (Shlomo Pongratz)   
- IB/ipoib: Add RSS and TSS support for datagram mode (Shlomo Pongratz)   
- IB/ipoib: Implement vectorization restructure as  pre-step for TSS/RSS (Shlomo Pongratz)   
- eipoib: addon flags (Yishai Hadas)   
- ib/ipoib: Add support in IPoIB instance (netdevice) functions as a VIF (Erez Shitrit)   
- ib/ipoib: add support for clones / multiple childs  on the same partitions (Or Gerlitz)   
- mlx4_core: Fix flow steering backword compatability to old FW's (Amir Vadai)   
- RDMA/ucm: disable tuning the max listen backlog in debug kernel (Dotan Barak)   
- mlx4_core: fix memtrack algoritm to identify non trackable mem allocation (Moshe Lazer)   
- core, srp, mlx4_en: Adjustments to patch set which rebased to kernel 3.7 (Jack Morgenstein)   
- mlx4_core, mlx4_ib, mlx4_en: match fs promisc enums to new PRM names (Hadar Hen Zion)   
- RDMA/ib_core: add support for iWarp multicast acceleration over IB_QPT_RAW_PACKET QP type (Solves RM #100087) (Marcel Apfelbaum)   
- mlx4_core, mlx4_ib: Adding flow steering ibdump support (Hadar Hen Zion)   
- mlx4_core: Update minimum size for log_num_qp to 18 (Moshe Lazer)   
- mlx4_en: fix race in join/leave multicast flow (Eugenia Emantayev)   
- mlx4_ib: allow_loopback flag shouldn't set hardcoded (Hadar Hen Zion)   
- mlx4_ib:Add ipoib qpn for IB unicast flow steering (Hadar Hen Zion)   
- net/mlx4: remove BUG_ON in case of an error (Dotan Barak)   
- mlx4_core: allow_loopback flag is corrupted (Amir Vadai)   
- mlx4_ib : add module parameter that maps IB device index to device function number (Eli Cohen)   
- sys_tune: enable sys_tune only if APM MODULE configured (Eugenia Emantayev)   
- mlx4_en: add defines for supported link speed (Eugenia Emantayev)   
- mlx4_en: fill truesize field in skb (Eugenia Emantayev)   
- sys_tune: add sys_tune for cpu tuning for better performance (Eugenia Emantayev)   
- net/mlx4: fix memory leaks in guest OS in case of error flow (Dotan Barak)   
- mlx4_core, mlx4_ib: Have enough room in steering range for pkey interfaces (Amir Vadai)   
- mlx4_ib: fix kernel crash when steering QPN's range is big (Amir Vadai)   
- mlx4_en: remove all queues empty condition for loopback test (Eugenia Emantayev)   
- mlx4_en: correct calculation of mtu size (Yishai Hadas)   
- mlx4_en: merge adaptive moderation logic/values from 1.5.9 (Eugenia Emantayev)   
- mlx4_ib: Adapt driver to changes in steering range API changes in firmware (Eitan Rabin)   
- mlx4_en, mlx4_ib: make QP steering range hardcoded (Amir Vadai)   
- net/mlx4: return bad error status to caller function in case of error (Dotan Barak)   
- mlx4_en: avoid cache miss in GRO flow (Eugenia Emantayev)   
- mlx4_en: no IP_ALIGN for scatter entries (Eugenia Emantayev)   
- mlx4_en: selecting neighbour core for TX interrupts (Eugenia Emantayev)   
- mlx4_en: NAPI on TX side (Eugenia Emantayev)   
- mlx4_en: fix kernel panic when accessing uninitialized mutex (Eugenia Emantayev)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- net/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- net/mlx4: print return values in-case of called function failures (Dotan Barak)   
- net/mlx4: add explicit message if user ask too few QPs (Dotan Barak)   
- ib_core: fix contig overflow over 2GB (Yishai Hadas)   
- mlx4/IB: disables user mode RAW QP VLAN stripping in the RX (Dotan Barak)   
- mlx4_en: fix kernel panic caused by null pointer dereference (Eugenia Emantayev)   
- ib/core: Remove annoying message. (Erez Shitrit)   
- mlx4_core: Fixing leackage of SW multicast entries. (Yevgeny Petrilin)   
- mlx4_en: set netif_carrier off when port stopped (Eugenia Emantayev)   
- mlx4_en: Adding info when TX timeout ocures (Yevgeny Petrilin)   
- mlx4_en: Fixing race when closing TX queue (Eugenia Emantayev)   
- mlx4_en: fix timestamping for gro flow (Eugenia Emantayev)   
- mlx4_en: fix a race between napi poll function and RX ring cleanup (Eugenia Emantayev)   
- mlx4_en: Removed failed adding vlan and not found vlan prints. (Eugenia Emantayev)   
- mlx4_en: move register_netdev() to the end of mlx4_en_init_netdev() (Eugenia Emantayev)   
- mlx4_en: Fixed no traffic bug when disable port during promisc mode in a loop. (Aviad Yehezkel)   
- mlx4_en: Do not disable vlan filter during promisc. (Eugenia Emantayev)   
- mlx4_core: open 4 msi-x vectors for multifunction (Eugenia Emantayev)   
- et/mlx4_core: make sure that err is non-zero in __mlx4_add_one error flow. (Jack Morgenstein)   
- mlx4_core: check that number of QP per MCG entry was not exceeded when adding to the default MCG entry (Alexander Guller)   
- mlx4_core: Expose mlx4_net_trans_rule_hw_ctrl structure fields (Hadar Hen Zion)   
- net/mlx4_core: fix memory leak in error flow of flow_spec_to_net_rule() (Dotan Barak)   
- net/mlx4_core: If memory allocation failed, return error to upper function (Dotan Barak)   
- mlx4_ib: fix memory leak if QP creation failed (Dotan Barak)   
- mlx4_ib: Fix IPoIB flow steering after broken by the TSS/RSS support commit (Hadar Hen Zion)   
- mlx4_ib: Bug fix - allow attaching L2 and L3 rules using ibv_attach_flow (Hadar Hen Zion)   
- net/mlx4_core: reduce the stack usage of the function mlx4_init_hca() (Dotan Barak)   
- ib/core: add prints to the cm module. (Erez Shitrit)   
- rds: fix error flow handling (Dotan Barak)   
- mlx4/IB: add a message print when the logical link goes up/down (Dotan Barak)   
- mlx4/ib: clean memory for EQs in case of error flow (Dotan Barak)   
- mlx4/IB: remove proc entries in case of bad flow (Dotan Barak)   
- net/mlx4_core: set used number of MTTs when using auto-detection (Dotan Barak)   
- net/mlx4_core: the number of MTTs should consider log_mtts_per_seg (Dotan Barak)   
- mlx4/IB: remove RD diagnostics counters (Dotan Barak)   
- ib_core: check that DMA mapping was successful (Dotan Barak)   
- mlx4_en: remove an unnecessary test if maxrate is NULL (Dotan Barak)   
- ib: cmem rlimit support (Yishai Hadas)   
- net/mlx4_core: limit to 4TB of memory registration (Yishai Hadas)   
- net/mlx4_core: enable 8TB of memory registration (Yishai Hadas)   
- net/mlx4_core: num mtt issues (Yishai Hadas)   
- mlx4_en: do dump eth statistics under mutex (Eugenia Emantayev)   
- net/mlx4_core: make sure that negative array index isn't used (Dotan Barak)   
- mlx4_en: fixing the condition before releasing resources (Dotan Barak)   
- IB/mlx4: fix compilation warning (Dotan Barak)   
- IB/mlx4: Prevent from all of the users in the system to clear the diag counters (Dotan Barak)   
- IB/core: Fix compilation warning in kernel 3.5+ (Dotan Barak)   
- mlx4_ib: Partial fix for ipoib SRIOV (Hadar Hen Zion)   
- mlx4_ib: prevent mixing enum mlx4_ib_qp_flags type with enum ib_qp_create_flags type (Saeed Mahameed)   
- IB/core: add module parameter to allow a non-root user to open a RAW QP (Dotan Barak)   
- mlx4_en: returning NETIF_F_GRO flag to dev->features (Yevgeny Petrilin)   
- mlx4_ib: add blue flame support for kernel consumers (Eli Cohen)   
- net/mlx4_core: add sanity check when creating bitmap structure (Dotan Barak)   
- mlx4_core: supporting 64b counters (Vu Pham)   
- ib_core: supporting 64b counters using PMA_COUNTERS_EXT mad (Vu Pham)   
- mlx4_core: fix error flow in case mlx4_reset failed (Dotan Barak)   
- net/mlx4_core: unmap clear register in case of error flow (Dotan Barak)   
- mlx4_core: support suspend/resume events (Eli Cohen)   
- srp: don't release resources if the add_one failed (Dotan Barak)   
- mlx4_en: Fixed memory leak in case of error flow (Dotan Barak)   
- ib_core: fix NULL pointer dereference (Dotan Barak)   
- mlx4_en: queue stop/start counters per ring (Yevgeny Petrilin)   
- mlx4_en: Using atomic counter to decide when queue is full. (Yevgeny Petrilin)   
- IB/mlx4: Add support for RSS and TSS QP groups (Shlomo Pongratz)   
- IB/core: Add RSS and TSS QP groups (Shlomo Pongratz)   
- mlx4_en: Data path structures are allocated per numa node. (Yevgeny Petrilin)   
- mlx4_core: ICM pages are allocated on device NUMA node (Yevgeny Petrilin)   
- mlx4_en: Datapath resources allocated separately (Yevgeny Petrilin)   
- mlx4_en: fix compilation error on 3.5 (Eugenia Emantayev)   
- mlx4_en: add timestamp support (Eugenia Emantayev)   
- mlx4_core: read hca frequency and map internal clock (Eugenia Emantayev)   
- mlx4_core: add timestamp device capability (Eugenia Emantayev)   
- mlx4_core: For flow steering unicast ipoib support added new flag to IB header check (Hadar Hen Zion)   
- mlx4_ib: contig support for control objects (Yishai Hadas)   
- mlx4: Setting Ethernet port even if interface is not being brought up (Yevgeny Petrilin)   
- mlx4: Enable fast_drop option (Yevgeny Petrilin)   
- mlx4_en: suppress page allocation failure warnings (Yevgeny Petrilin)   
- mlx4_en: Allocation order is 0 on 32 bit systems to avoid allocation failures (Yevgeny Petrilin)   
- mlx4: Allow high_rate_steer (A0 mode) (Yevgeny Petrilin)   
- mlx4: Respond to operation request by FW. (Yevgeny Petrilin)   
- mlx4_core: fix wrong comment about the reason of subtract one from the max_cqes (Dotan Barak)   
- ib/core: change module_param to module_param_named call. (Erez Shitrit)   
- ib_core: Use weak ordering for data registered memory (Eli Cohen)   
- IB/core - Don't modify outgoing DR SMP if first part is LID routed (Ralph Campbell)   
- mlx4_core: remove use_prio module parameter (Eugenia Emantayev)   
- net/mlx4: adjust initial value of vl_cap in mlx4_SET_PORT (Or Gerlitz)   
- mlx4_core: Error message on mtt allocation failure (Marcel Apfelbaum)   
- mlx4_core: fail device init if num_vfs is negative. (Jack Morgenstein)   
- IB/core: Control number of retries for SA to leave an MCG (Dotan Barak)   
- mlx4: More mverbs support (Dotan Barak)   
- mlx4: add warning prints in case of command timeouts (Dotan Barak)   
- mlx4_core: Increased Command Timeout for NOP operation (Yevgeny Petrilin)   
- mlx4: Disable BF on PPC (Dotan Barak)   
- mlx4: reducing wait during SW reset for 500 msecs (Dotan Barak)   
- mlx4_ib: check for FW version which properly supports resize_cq. (Dotan Barak)   
- mlx4_ib: Do not enable blueflame sends if write combining is not available (Jack Morgenstein)   
- IB/core: Fix create_qp issue relates to qp group type (Yishai Hadas)   
- mlx4_core: log_num_mtt handling (Yishai Hadas)   
- mlx4_core: adding 'set_4k_mtu' module parameter as an obsolete one (Yishai Hadas)   
- mlx4_ib: Fix the SQ size of an RC QP to support masked atomic operation (Dotan Barak)   
- {NET,IB}/mlx4: 64 byte CQE/EQE support (Or Gerlitz)   
- ib_core: cmem handling to prevent redundant WARN (Yishai Hadas)   
- ib_core: rlimit fix when cmem alloc has failed (Yishai Hadas)   
- IB/mlx4_ib: use 8 bits in mlx4_ib_mmap for command ID instead of 3 (Yishai Hadas)   
- IB: enable shared mr functionality (Yishai Hadas)   
- IB/mlx4_ib: shared mr initial handling (Yishai Hadas)   
- IB/core: infrastructure extensions to be used for shared mr functionality (Yishai Hadas)   
- IB/mlx4_ib: 'proc' handling (Yishai Hadas)   
- IB: reg_user_mr changes to include a new field named mr_id (Yishai Hadas)   
- IB/core: ib_uverbs_reg_mr flow change (Yishai Hadas)   
- ib_core: symmetric issues with user space. (Yishai Hadas)   
- mlx4_ib: Use optimal numbers of MTT entries. (Yishai Hadas)   
- mlx4_ib: implement get_unmapped_area (Yishai Hadas)   
- ib_core: Exporting capability to control the alignment of the virtual address returned by mmap. (Yishai Hadas)   
- mlx4_ib: Exporting to user space the contiguous allocation capability by mmap extension (Yishai Hadas)   
- ib_core: Extending umem to support contiguous memory operations. (Yishai Hadas)   
- mlx4: make firmware diagnostic counters available via sysfs (Dotan Barak)   
- mlx4: enable discarding/passing multicast loopback packets by FW/HW. (Dotan Barak)   
- mlx4_ib: set write-combining flag for userspace blueflame pages (Dotan Barak)   
- mlx4_core: limit min profile numbers (Dotan Barak)   
- mlx4_core: allow to use 0 in log_mtts_per_seg (Dotan Barak)   
- mlx4_core: enable changing default max HCA resource limits. (Dotan Barak)   
- cma: add module parameter to the response timeout (Arlin Davis)   
- mlx4: Add mverbs support (Dotan Barak)   
- mlx4_core: replace sscanf() with simple_strtol() (Dotan Barak)   
- mlx4: increase the command timeout to 60 seconds (Dotan Barak)   
- mlx4_core, mlx4_ib, cma, ipoib: Add IB UC flow steering for datagram QP's. (Amir Vadai)   
- mlx4_ib: add support to flow steering attach with rdmacm applications. (Hadar Hen Zion)   
- rdma_cm: Implement rdma_get_l2 (Nir Muchtar)   
- ib_uverbs: Export ib_attach_flow and ib_detach_flow to userspace. (Nir Muchtar)   
- mlx4_ib: Add support for ib_attach_flow and ib_detach_flow. (Nir Muchtar)   
- ib_core: Implement ib_attach_flow ib_detach_flow (Nir Muchtar)   
- mlx4_core: enable RoCE under SRIOV (Jack Morgenstein)   
- mlx4_core: Adjust update-gids task for RoCE running under SRIOV (Jack Morgenstein)   
- mlx4_ib: In sysfs, do not allow changing the paravirtualization mapping for pkeys (Jack Morgenstein)   
- {IB,ETH}/mlx4: Adjust QP1 multiplexing and QP creation for RoCE/SRIOV (Jack Morgenstein)   
- en/mlx4_core: For RoCE, allow slaves to set the GID entry at that slave's index (Jack Morgenstein)   
- {IB,ETH}/mlx4: Add ref counting to port MAC table for RoCE (Jack Morgenstein)   
- mlx4_core: Add mechanism for non trackable mem free (Moshe Lazer)   
- memtrack: fix get_page/put_page tracking (Jack Morgenstein)   
- Added memtrack (Vladimir Sokolovsky)   
- Revert "mlx4_en: fix allocation of CPU affinity reverse-map" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Call skb_dst_drop() once skb is enqueued for sending" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Increase block layer timeout" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Eliminate state SRP_TARGET_CONNECTING" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Keep processing commands during host removal" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Simplify SCSI error handling" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Introduce srp_handle_qp_err()" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Process all error completions" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Introduce the helper function srp_remove_target()" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Suppress superfluous error messages" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Eliminate state SRP_TARGET_DEAD" (Ajaykumar Hotchandani)   
- Revert "IB/srp: destroy and recreate QP and CQs when reconnecting" (Ajaykumar Hotchandani)   
- Revert "IB/srp: send disconnect request without waiting for CM timewait exit" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Allow SRP disconnect through sysfs" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Track connection state properly" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Avoid sending a task management function needlessly" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Avoid endless SCSI error handling loop" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Fail I/O requests if the transport is offline" (Ajaykumar Hotchandani)   
- Revert "rds: limit the size allocated by rds_message_alloc()" (Ajaykumar Hotchandani)   
- Revert "net: rds: use this_cpu_* per-cpu helper" (Ajaykumar Hotchandani)   
- Revert "IB/rds: Correct ib_api use with gs_dma_address/sg_dma_len" (Ajaykumar Hotchandani)   
- Revert "IB/rds: suppress incompatible protocol when version is known" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: remove __dev* attributes" (Ajaykumar Hotchandani)   
- Revert "mlx4: change TX coalescing defaults" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Fix send lockup due to missed TX completion" (Ajaykumar Hotchandani)   
- Revert "mlx4: 64-byte CQE/EQE support" (Ajaykumar Hotchandani)   
- Revert "mlx4_en: Remove remnants of LRO support" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Can set maxrate only for TC0" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Set number of rx/tx channels using ethtool" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Use generic etherdevice.h functions." (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Add support for destination MAC in steering rules" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Add QPN enforcement for flow steering rules set by VFs" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix error flow in the flow steering wrapper" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Adjustments to Flow Steering activation logic for SR-IOV" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Allow choosing flow steering mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_core: Set number of msix vectors under SRIOV mode to firmware defaults" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix advertisement of wrong PF context behaviour" (Ajaykumar Hotchandani)   
- Revert "mlx4_en: fix allocation of device tx_cq" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Initialize RFS filters lock and list in init_netdev" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Disable RFS when running in SRIOV mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Fix bridged vSwitch configuration for non SRIOV mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Fix TX moderation info loss after set_ringparam is called" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix potential deadlock in mlx4_eq_int()" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Fix crash due to skb double destruct" (Ajaykumar Hotchandani)   
- Revert "IB/mlx4: Fix spinlock order to avoid lockdep warnings" (Ajaykumar Hotchandani)   
- Revert "RDMA/cm: Change return value from find_gid_port()" (Ajaykumar Hotchandani)   

* Fri Aug 2 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-7.el6uek] 
- qla4xxx: Updated driver version to 5.03.00.03.06.02-uek3 (Tej Parkash) [Orabug: 17220566]  
- libiscsi: Add missing prints for session and connection sysfs attrs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Add a missing break statement (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Export more firmware info in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Only BIOS boot target entries should be at index 0 and 1. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: discovery_parent_idx can be shown without any check. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Set IPv6 traffic class if device type is IPv6. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Use discovery_parent_idx instead of discovery_parent_type (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Allow removal of failed session using logout. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Added new boot entries in the session sysfs (Eddie Wai) [Orabug: 17220566]  
- treewide: Fix typo in printk (Masanari Iida) [Orabug: 17220566]  
- iscsi class, qla4xxx: fix sess/conn refcounting when find fns are used (Mike Christie) [Orabug: 17220566]  
- qla4xxx: Fix iocb_cnt calculation in qla4xxx_send_mbox_iocb() (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Assign values using correct datatype (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Fix smatch warnings (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Fix sparse warning for qla4xxx_sysfs_ddb_tgt_create (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Silence gcc warning (Vikas Chaudhary) [Orabug: 17220566]  
- iscsi_tcp: support PF_MEMALLOC/__GFP_MEMALLOC (Mike Christie) [Orabug: 17220566]  
- libiscsi: avoid unnecessary multiple NULL assignments (Masatake YAMATO) [Orabug: 17220566]  
- qla4xxx: Added print statements to display AENs (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Use correct value for max flash node entries (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Restrict logout from boot target session using session id (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Use correct flash ddb offset for ISP40XX (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Replace dev type macros with generic portal type macros (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Declare portal type string macros for generic use (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Add flash node mgmt support (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: export function iscsi_switch_str_param (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Add flash node mgmt support (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Skip retry of initialize_adapter for ISP80XX (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Assign correct CHAP table address to FLT (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Added missing check for ISP83XX in CHAP related functions (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Fixed request queue count manipulation on response path (Tej Parkash) [Orabug: 17220566]  
- qla4xxx: Fix debug level to avoid floods of same message (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Pass correct LUN address to firmware in case of lun_reset (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Fix double reset in case of firmware hung for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Set graceful reset bit for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Boot from SAN fix for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Take E-port out of reset before disabling pause frames (Manish Dusane) [Orabug: 17220566]  
- scsi: replace obsolete NLMSG_* with type safe nlmsg_* (Hong zhi guo) [Orabug: 17220566]  
- treewide: Fix typos in printk and comment (Masanari Iida) [Orabug: 17220566]  
- qla4xxx: don't free NULL dma pool (Dan Carpenter) [Orabug: 17220566]  
- qla4xxx: Fix return code for qla4xxx_session_get_param. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: wait for boot target login response during probe. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Added support for force firmware dump (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Re-register IRQ handler while retrying initialize of adapter (Poornima Vonti) [Orabug: 17220566]  
- qla4xxx: Throttle active IOCBs to firmware limits (Karen Higgins) [Orabug: 17220566]  
- qla4xxx: Remove unnecessary code from qla4xxx_init_local_data (Karen Higgins) [Orabug: 17220566]  
- qla4xxx: Quiesce driver activities while loopback (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Rename MBOX_ASTS_IDC_NOTIFY to MBOX_ASTS_IDC_REQUEST_NOTIFICATION (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Add spurious interrupt messages under debug level 2 (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Correct the validation to check in get_sys_info mailbox (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Pass correct function param to qla4_8xxx_rd_direct (Vikas Chaudhary) [Orabug: 17220566]  
- scsi_transport_iscsi: export iscsi class session's target_id in sysfs. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Fix memory corruption issue in qla4xxx_get_ep_fwdb. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Allow reset in link down case (Harish Zunjarrao) [Orabug: 17220566]  
- qla4xxx: Fix MBOX intr switching from polling to intr mode for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- config: enable numa balancing (Jerry Snitselaar) [Orabug: 17018504]  
- config: disable Transparent Hugepages (Jerry Snitselaar) [Orabug: 17251843]  
- be2net: Updating version number (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: Fix to avoid hardware workaround when not needed (Sarveshwar Bandi) [Orabug: 17252720]  
- net/trivial: replace numeric with standard PM state macros (Yijing Wang) [Orabug: 17252720]  
- be2net: Fix 32-bit DMA Mask handling (Somnath Kotur) [Orabug: 17252720]  
- be2net: Implement initiate FW dump feature for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix crash on 2nd invocation of PCI AER/EEH error_detected hook (Somnath Kotur) [Orabug: 17252720]  
- be2net: Mark checksum fail for IP fragmented packets (Somnath Kotur) [Orabug: 17252720]  
- be2net: Trim padded packets for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Pad skb to meet min Tx pkt size in lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: cleanup be_get_drvinfo() (Somnath Kotur) [Orabug: 17252720]  
- be2net: refactor HW workarounds in be_xmit() (Sathya Perla) [Orabug: 17252720]  
- be2net: bug fix on returning an invalid nic descriptor (Wei Yang) [Orabug: 17252720]  
- be2net: Avoid double insertion of vlan tags. (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: disable TX in be_close() (Sathya Perla) [Orabug: 17252720]  
- be2net: fix EQ from getting full while cleaning RX CQ (Sathya Perla) [Orabug: 17252720]  
- be2net: fix payload_len value for GET_MAC_LIST cmd req (Sathya Perla) [Orabug: 17252720]  
- be2net: provision VF resources before enabling SR-IOV (Sathya Perla) [Orabug: 17252720]  
- be2net: Fix to fail probe if MSI-X enable fails for a VF (Somnath Kotur) [Orabug: 17252720]  
- be2net: avoid napi_disable() when it has not been enabled (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix firmware download for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix to receive Multicast Packets when Promiscuous mode is enabled on certain devices (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to show tx priority pause counter in ethtool -S (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to use 32-bit stats to report rx_drops_no_fragment (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to use version 2 of cq_create for SkyHawk-R devices (Ajit Khaparde) [Orabug: 17252720]  
- be2net: FLR must be first cmd issued to Lancer FW (Kalesh AP) [Orabug: 17252720]  
- be2net: Use GET_FUNCTION_CONFIG V1 cmd (Kalesh AP) [Orabug: 17252720]  
- be2net: Fix to show wol disabled/enabled state correctly. (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: Fixed memory leak (Suresh Reddy) [Orabug: 17252720]  
- be2net: Avoid diagnostic test in certain versions of firmware to avoid NIC freeze. (Suresh Reddy) [Orabug: 17252720]  
- be2net: Renamed rx_address_mismatch_errors to rx_address_filtered (Suresh Reddy) [Orabug: 17252720]  
- be2net: Add support for setting and getting rx flow hash options (Suresh Reddy) [Orabug: 17252720]  
- be2net: Fix PVID tag offload for packets with inline VLAN tag. (Ajit Khaparde) [Orabug: 17252720]  
- be2net: fix a Tx stall bug caused by a specific ipv6 packet (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Remove an incorrect pvid check in Tx (Ajit Khaparde) [Orabug: 17252720]  
- be2net: enable IOMMU pass through for be2net (Craig Hada) [Orabug: 17252720]  
- be2net: Use GET_PROFILE_CONFIG V1 cmd for BE3-R (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Avoid flashing BE3 UFI on BE3-R chip. (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Don't log "Out of MCCQ wrbs" error (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Use TXQ_CREATE_V2 cmd (Vasundhara Volam) [Orabug: 17252720]  
- be2net: take care of __vlan_put_tag return value (Ivan Vecera) [Orabug: 17252720]  
- be2net: remove unused variable 'sge' (Ivan Vecera) [Orabug: 17252720]  
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of memset(, 0) (Joe Perches) [Orabug: 17252720]  
- drivers:net: Remove dma_alloc_coherent OOM messages (Joe Perches) [Orabug: 17252720]  
- be2net: Use new F/W mailbox cmd to manipulate interrupts. (Somnath Kotur) [Orabug: 17252720]  
- be2net: enable interrupts in be_probe() (RoCE and other ULPs need them) (Somnath Kotur) [Orabug: 17252720]  
- be2net: Update copyright year (Vasundhara Volam) [Orabug: 17252720]  
- be2net: use CSR-BAR SEMAPHORE reg for BE2/BE3 (Sathya Perla) [Orabug: 17252720]  
- benet: Wait f/w POST until timeout (Gavin Shan) [Orabug: 17252720]  
- be2net: remove BUG_ON() in be_mcc_compl_is_new() (Sathya Perla) [Orabug: 17252720]  
- be2net: update driver version to 4.6.x (Sathya Perla) [Orabug: 17252720]  
- be2net: fix re-loaded PF driver to re-gain control of its VFs (Sathya Perla) [Orabug: 17252720]  
- ethtool: fix drvinfo strings set in drivers (Jiri Pirko) [Orabug: 17252720]  
- block: do not pass disk names as format strings (Kees Cook) [Orabug: 17230056] {CVE-2013-2851} 
- libceph: Fix NULL pointer dereference in auth client code (Tyler Hicks) [Orabug: 17230095] {CVE-2013-1059} 
- Btrfs: re-add root to dead root list if we stop dropping it (Josef Bacik)   
- Btrfs: fix lock leak when resuming snapshot deletion (Josef Bacik)   
- Btrfs: only do the tree_mod_log_free_eb if this is our last ref (Josef Bacik)   
- Btrfs: hold the tree mod lock in __tree_mod_log_rewind (Josef Bacik)   
- Btrfs: fix oops when recovering the file data by scrub function (Miao Xie)   
- Btrfs: unlock extent range on enospc in compressed submit (Josef Bacik)   
- btrfs: do away with non-whole_page extent I/O (Alexandre Oliva)   
- btrfs: don't stop searching after encountering the wrong item (Gabriel de Perthuis)   
- Btrfs: don't call readahead hook until we have read the entire eb (Josef Bacik)   
- Btrfs: fix possible infinite loop in slow caching (Josef Bacik)   
- Btrfs: fix lockdep warning (Josef Bacik)   
- Btrfs: don't force pages under writeback to finish when aborting (Josef Bacik)   
- Btrfs: fix unlock after free on rewinded tree blocks (Jan Schmidt)   
- Btrfs: fix accessing the root pointer in tree mod log functions (Jan Schmidt)   
- Btrfs: fix tree mod log regression on root split operations (Jan Schmidt)   
- Btrfs: fix bad extent logging (Josef Bacik)   
- Btrfs: log ram bytes properly (Josef Bacik)   
- Btrfs: fix memory leak in btrfs_create_tree() (Tsutomu Itoh)   
- Btrfs: fix warning of free_extent_map (Liu Bo)   
- Btrfs: fix warning when creating snapshots (Liu Bo)   
- Btrfs: fix missing deleted items in btrfs_clean_quota_tree (Wang Shilong)   
- Btrfs: fix memory leak of log roots (Liu Bo)   
- Btrfs: fix NULL pointer after aborting a transaction (Liu Bo)   
- Btrfs: do not change inode flags in rename (Liu Bo)   
- Btrfs: use reserved space for creating a snapshot (Liu Bo)   
- Btrfs: make sure NODATACOW also gets NODATASUM set (Josef Bacik)   
- Btrfs: fix backref walking race with tree deletions (Jan Schmidt)   
- Btrfs: fix wrong outstanding_extents when doing DIO write (Miao Xie)   
- Btrfs: fix cleaner thread not working with inode cache option (Liu Bo)   
- Btrfs: fix the deadlock between the transaction start/attach and commit (Miao Xie)   
- Btrfs: eliminate a use-after-free in btrfs_balance() (Ilya Dryomov)   
- Btrfs: fix deadlock due to unsubmitted (Miao Xie)   
- Btrfs: fix memory leak of pending_snapshot->inherit (Miao Xie)   
- Btrfs: fix the race between bio and btrfs_stop_workers (Miao Xie)   
- Btrfs: handle errors in compression submission path (Josef Bacik)   
- Btrfs: rework the overcommit logic to be based on the total size (Josef Bacik)   
- Btrfs: unreserve space if our ordered extent fails to work (Josef Bacik)   
- Btrfs: fix how we discard outstanding ordered extents on abort (Josef Bacik)   
- Btrfs: fix freeing delayed ref head while still holding its mutex (Josef Bacik)   
- Btrfs: do not overcommit if we don't have enough space for global rsv (Josef Bacik)   
- Btrfs: remove extent mapping if we fail to add chunk (Josef Bacik)   
- Btrfs: fix chunk allocation error handling (Josef Bacik)   
- Btrfs: fix crash in log replay with qgroups enabled (Arne Jansen)   

* Tue Jul 30 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-6.el6uek] 
- mpt2sas: update from 16.05.01.00 to 17.00.00.00 (Jerry Snitselaar) [Orabug: 17237382]  
- enable VMware module vsock,vmw_vmci,vmw_vsock_vmci_transport (Vaughan Cao) [Orabug: 16957210]  
- Backport VMCI and vSockets from 3.10 (Andy King) [Orabug: 16957210]  
- vmxnet3: prevent div-by-zero panic when ring resizing uninitialized dev (Bhavesh Davda) [Orabug: 17215008]  
- ipv6: ip6_sk_dst_check() must not assume ipv6 dst (Eric Dumazet) [Orabug: 17079717]  
- build,drm: enable building of vmwgfx driver (Jerry Snitselaar) [Orabug: 17158893]  
- be2iscsi: Bump the driver version to 10.0.467.0 (John Soni Jose) [Orabug: 17233074]  
- be2iscsi: Fix issue in passing the exp_cmdsn and max_cmdsn (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix possible reentrancy issue in be_iopoll (Shlomo Pongratz) [Orabug: 17233074]  
- be2scsi: Update copyright dates to 2013 (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix checking Adapter state while establishing CXN (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix dynamic CID allocation Mechanism in driver (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi : Fix the NOP-In handling code path (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix the Port Link Status issue (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix displaying the Active Session Count from driver (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix displaying the FW Version from driver. (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix support for DEFQ extension (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MACRO for checking the adapter type (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix freeing CXN specific driver resources. (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MSIX support in SKH-R to 32 (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MBX Command issues (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix returning Failure when MBX fails with Insufficient buffer error (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix lack of uninitialize pattern to FW (Jayamohan Kallickal) [Orabug: 17233074]  
- treewide: Fix typo in printk and comments (Masanari Iida) [Orabug: 17233074]  
- neighbour: fix a race in neigh_destroy() (Eric Dumazet)   
- mpt3sas: Bump driver version to v02.100.00.00 (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: when async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: MPI2.5 Rev F v2.5.1.1 specification (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: Infinite loops can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: fix for kernel panic when driver loads with HBA conected to non LUN 0 configured expander (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: Updated the Hardware timing requirements (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: 2013 source code copyright (Sreekanth Reddy) [Orabug: 17187623]  
- fib_trie: potential out of bounds access in trie_show_stats() (Jerry Snitselaar) [Orabug: 17215539]  
- Revert "xen/pat: Disable PAT using pat_enabled value." (Jerry Snitselaar) [Orabug: 17176404]  
- sxge: Check link state before xmit (Joe Jin) [Orabug: 17201220]  

* Tue Jul 23 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-5.el6uek] 
- writeback fix bdi thread race in mark_inode_dirty (UEK3) (Srinivas Eeda)   
- mpt2sas: update to LSI version 16.05.01.00 (Maxim Uvarov) [Orabug: 16730165]  
- megaraid_sas driver update from 06.504.01.00-rc1 to version 06.600.18.00 (Maxim Uvarov) [Orabug: 17177382]  
- Specfile changes for sparc (Dave Kleikamp)   
- sunvdc: fix typo and remove unused function (Dave Kleikamp)   
- sparc: rcu_needs_cpu() needs second argument (Dave Kleikamp)   
- sparc: add back TIF_FREEZE to fix a build break (Dave Kleikamp)   
- sparc: fix typo in smp_64.h (Dave Kleikamp)   
- writeback: Fix periodic writeback after fs mount (Jan Kara) [Orabug: 17185874]  
- [SCSI] scsi_transport_iscsi: fix error return code in iscsi_transport_init() (Wei Yongjun) [Orabug: 17153681]  

* Fri Jul 19 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-4.el6uek] 
- configs: turn on sxge (Maxim Uvarov)   
- [net] add sxge and sxgevf drivers (Maxim Uvarov) [Orabug: 16443168]  
- sparc64 - userspace VA layout (bob picco)   
- kernel: freezer: restore TIF_FREEZE (Sasha Levin)   
- Revert "megaraid_sas: Big endian support" (Maxim Uvarov) [Orabug: 17167688]  
- bnx2x correct firmwares ihex (Maxim Uvarov) [Orabug: 17034501]  
- config changes from uek2 (Allen Pais)   
- sparc64: fatal trap should stop all cpus (Dave Kleikamp)   
- sunvdc TX TEMPORARY workaround (Allen Pais)   
- vdisk geometry (Allen Pais)   
- sunvet (Allen Pais)   
- sunvdc cdrom support (Allen Pais)   
- xen-netfront: use skb_partial_csum_set() to simplify the codes (Li RongQing)   
- xen-netfront: split event channels support for Xen frontend driver (Wei Liu)   
- xen-netfront: avoid leaking resources when setup_netfront fails (Wei Liu)   
- xen-netfront: reduce gso_max_size to account for max TCP header (Wei Liu)   
- xen-netfront: frags -> slots in log message (Wei Liu)   
- xen-netfront: frags -> slots in xennet_get_responses (Wei Liu)   
- xen-netfront: remove unused variable `extra' (Wei Liu)   
- xen-netback: xenbus.c: use more current logging styles (Wei Liu)   
- xen: Use more current logging styles (Joe Perches)   
- xen-netback: double free on unload (Dan Carpenter)   
- xen-netback: don't de-reference vif pointer after having called xenvif_put() (Jan Beulich)   
- perf sparc4 dwarf (Allen Pais)   
- xen-netback: split event channels support for Xen backend driver (Wei Liu)   
- xen-netback: enable user to unload netback module (Wei Liu)   
- xen-netback: remove dead code (Wei Liu)   
- xen-netback: better names for thresholds (Wei Liu)   
- xen-netback: avoid allocating variable size array on stack (Wei Liu)   
- xen-netback: remove redundent parameter in netbk_count_requests (Wei Liu)   
- xen-netback: don't disconnect frontend when seeing oversize packet (Wei Liu)   
- xen-netback: coalesce slots in TX path and fix regressions (Wei Liu)   
- xen-netback: fix sparse warning (stephen hemminger)   
- do_rt_sigreturn - minor clean up (bob picco)   
- remove sparc support (bob picco)   
- cpu_idle - add rcu needs cpu to yield decision (bob picco)   
- sparc64_yield - consolidate conditions for enter  yield (Allen Pais)   
- small clean up - isolate CPU_HOTPLUG in include file (Allen Pais)   
- xen-netback: remove skb in xen_netbk_alloc_page (Wei Liu)   
- Revert "xen: netback: remove redundant xenvif_put" (David S. Miller)   
- xen: netback: remove redundant xenvif_put (Andrew Jones)   
- xen-netback: allow changing the MAC address of the interface (Matt Wilson)   

* Wed Jul 10 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-3.el6uek] 
- xen/netback: correctly calculate required slots of skb. (Annie Li) [Orabug: 16934362]  
- megaraid_sas: Big endian support (Martin K. Petersen)   
- sparc/ldom sysfs now shows only CPUs assigned to VM, not all in MD (Allen Pais)   
- ixgbe: Look up MAC address on SPARC systems (Allen Pais)   
- bnx2x: update fw to 7.8.2 (Yuval Mintz)   
- x86 idle: remove mwait_idle() and "idle=mwait" cmdline param (Len Brown) [Orabug: 17034508]  
- Revert "xen/pci: Use PCI_MSIX_TABLE_BIR, not PCI_MSIX_FLAGS_BIRMASK" (Konrad Rzeszutek Wilk)   
- Revert "xen/pci: Used cached MSI-X capability offset" (Konrad Rzeszutek Wilk)   
- Revert "xen-pciback: more uses of cached MSI-X capability offset" (Konrad Rzeszutek Wilk)   
- xen-blkback: check the number of iovecs before allocating a bios (Roger Pau Monne)   
- xen: Convert printks to pr_<level> (Joe Perches)   
- xen/time: remove blocked time accounting from xen "clockchip" (Laszlo Ersek)   
- xen: ifdef CONFIG_HIBERNATE_CALLBACKS xen_*_suspend (Stefano Stabellini)   
- xen/pcifront: Deal with toolstack missing 'XenbusStateClosing' state. (Konrad Rzeszutek Wilk)   
- xen/time: Free onlined per-cpu data structure if we want to online it again. (Konrad Rzeszutek Wilk)   
- xen/time: Check that the per_cpu data structure has data before freeing. (Konrad Rzeszutek Wilk)   
- xen/time: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/time: Encapsulate the struct clock_event_device in another structure. (Konrad Rzeszutek Wilk)   
- xen/spinlock: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/smp: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/smp: Set the per-cpu IRQ number to a valid default. (Konrad Rzeszutek Wilk)   
- xen/smp: Introduce a common structure to contain the IRQ name and interrupt line. (Konrad Rzeszutek Wilk)   
- xen/smp: Coalesce the free_irq calls in one function. (Konrad Rzeszutek Wilk)   
- xen-pciback: fix error return code in pcistub_irq_handler_switch() (Wei Yongjun)   
- microcode_xen: Add support for AMD family >= 15h (Ian Campbell)   
- x86/microcode: check proper return code. (Ben Guthro)   
- xen: add CPU microcode update driver (Jeremy Fitzhardinge)   
- x86/cpa: Use pte_attrs instead of pte_flags on CPA/set_p.._wb/wc operations. (Konrad Rzeszutek Wilk)   
- Revert "xen/pat: Disable PAT support for now." (Konrad Rzeszutek Wilk)   
- Revert "xen/pat: Disable PAT using pat_enabled value." (Konrad Rzeszutek Wilk)   
- xen / ACPI / sleep: Register an acpi_suspend_lowlevel callback. (Konrad Rzeszutek Wilk)   
- x86 / ACPI / sleep: Provide registration for acpi_suspend_lowlevel. (Konrad Rzeszutek Wilk)   
- xen/smp: Fixup NOHZ per cpu data when onlining an offline CPU. (Konrad Rzeszutek Wilk)   
- xenbus_client.c: correct exit path for xenbus_map_ring_valloc_hvm (Wei Liu)   
- xen-pciback: more uses of cached MSI-X capability offset (Jan Beulich)   
- xen: Clean up apic ipi interface (Stefan Bader)   
- xenbus: save xenstore local status for later use (Aurelien Chartier)   
- xenbus: delay xenbus frontend resume if xenstored is not running (Aurelien Chartier)   
- xen: Fixed assignment error in if statement (Lisa Nguyen)   
- xen/xenbus: Fixed over 80 character limit issue (Lisa Nguyen)   
- xen/xenbus: Fixed indentation error in switch case (Lisa Nguyen)   
- xen/privcmd: fix condition in privcmd_close() (Dan Carpenter)   
- xen/pci: Used cached MSI-X capability offset (Bjorn Helgaas)   
- xen/pci: Use PCI_MSIX_TABLE_BIR, not PCI_MSIX_FLAGS_BIRMASK (Bjorn Helgaas)   
- xen: clear IRQ_NOAUTOEN and IRQ_NOREQUEST (Julien Grall)   
- xen: mask x2APIC feature in PV (Zhenzhong Duan)   
- xen: SWIOTLB is only used on x86 (Arnd Bergmann)   
- xen/spinlock: Fix check from greater than to be also be greater or equal to. (Konrad Rzeszutek Wilk)   
- xen/smp/pvhvm: Don't point per_cpu(xen_vpcu, 33 and larger) to shared_info (Konrad Rzeszutek Wilk)   
- xen/vcpu: Document the xen_vcpu_info and xen_vcpu (Konrad Rzeszutek Wilk)   
- xen/vcpu/pvhvm: Fix vcpu hotplugging hanging. (Konrad Rzeszutek Wilk)   
- xen: resolve section mismatch warnings in xen-acpi-processor (Ben Guthro)   
- xen: Re-upload processor PM data to hypervisor after S3 resume (v2) (Ben Guthro)   
- xen/smp: Unifiy some of the PVs and PVHVM offline CPU path (Konrad Rzeszutek Wilk)   
- xen/smp/pvhvm: Don't initialize IRQ_WORKER as we are using the native one. (Konrad Rzeszutek Wilk)   
- xen/spinlock: Disable IRQ spinlock (PV) allocation on PVHVM (Konrad Rzeszutek Wilk)   
- xen/spinlock: Check against default value of -1 for IRQ line. (Konrad Rzeszutek Wilk)   
- xen/time: Add default value of -1 for IRQ and check for that. (Konrad Rzeszutek Wilk)   
- xen/events: Check that IRQ value passed in is valid. (Konrad Rzeszutek Wilk)   
- xen/time: Fix kasprintf splat when allocating timer%d IRQ line. (Konrad Rzeszutek Wilk)   
- xen/smp/spinlock: Fix leakage of the spinlock interrupt line for every CPU online/offline (Konrad Rzeszutek Wilk)   
- xen/smp: Fix leakage of timer interrupt line for every CPU online/offline. (Konrad Rzeszutek Wilk)   
- xen kconfig: fix select INPUT_XEN_KBDDEV_FRONTEND (Andrew Jones)   
- xen: drop tracking of IRQ vector (Jan Beulich)   
- x86/xen: populate boot_params with EDD data (David Vrabel)   
- xen-blkfront: set blk_queue_max_hw_sectors correctly (Roger Pau Monne)   
- xen-blkback: workaround compiler bug in gcc 4.1 (Roger Pau Monne)   
- xen/blkback: Check for insane amounts of request on the ring (v6). (Konrad Rzeszutek Wilk)   
- xen/io/ring.h: new macro to detect whether there are too many requests on the ring (Jan Beulich)   
- xen/blkback: Check device permissions before allowing OP_DISCARD (Konrad Rzeszutek Wilk)  {CVE-2013-2140} 
- xen/blkback: Use physical sector size for setup (Stefan Bader)   
- xen-blkback/sysfs: Move the parameters for the persistent grant features (Konrad Rzeszutek Wilk)   
- xen-blkfront: Introduce a 'max' module parameter to alter the amount of indirect segments. (Konrad Rzeszutek Wilk)   
- xen-blkfront: use a different scatterlist for each request (Roger Pau Monne)   
- xen-blkback: allocate list of pending reqs in small chunks (Roger Pau Monne)   
- xen-block: implement indirect descriptors (Roger Pau Monne)   
- xen-blkback: expand map/unmap functions (Roger Pau Monne)   
- xen-blkback: make the queue of free requests per backend (Roger Pau Monne)   
- xen-blkback: move pending handles list from blkbk to pending_req (Roger Pau Monne)   
- xen-blkback: implement LRU mechanism for persistent grants (Roger Pau Monne)   
- xen-blkback: use balloon pages for all mappings (Roger Pau Monne)   
- xen-blkback: print stats about persistent grants (Roger Pau Monne)   
- xen/mmu: On early bootup, flush the TLB when changing RO->RW bits Xen provided pagetables. (Konrad Rzeszutek Wilk)   
- xen/events: Handle VIRQ_TIMER before any other hardirq in event loop. (Keir Fraser)   
- xen/events: avoid race with raising an event in unmask_evtchn() (David Vrabel)   
- xen/mmu: Move the setting of pvops.write_cr3 to later phase in bootup. (Konrad Rzeszutek Wilk)   
- xen/acpi-stub: Disable it b/c the acpi_processor_add is no longer called. (Konrad Rzeszutek Wilk)   
- xen-pciback: notify hypervisor about devices intended to be assigned to guests (Jan Beulich)   
- xen/acpi-processor: Don't dereference struct acpi_processor on all CPUs. (Konrad Rzeszutek Wilk)   
- xen/acpi: remove redundant acpi/acpi_drivers.h include (Liu Jinsong)   
- xen: arm: mandate EABI and use generic atomic operations. (Ian Campbell)   
- acpi: Export the acpi_processor_get_performance_info (Konrad Rzeszutek Wilk)   
- xen/pciback: Don't disable a PCI device that is already disabled. (Konrad Rzeszutek Wilk)   
- xenbus: fix compile failure on ARM with Xen enabled (Steven Noonan)   
- xen/pci: We don't do multiple MSI's. (Konrad Rzeszutek Wilk)   
- xen/pat: Disable PAT using pat_enabled value. (Konrad Rzeszutek Wilk)   
- xen/acpi: xen cpu hotplug minor updates (Liu Jinsong)   
- xen/acpi: xen memory hotplug minor updates (Liu Jinsong)   
- xen: event channel arrays are xen_ulong_t and not unsigned long (Ian Campbell)   
- xen: Send spinlock IPI to all waiters (Stefan Bader)   
- xen: introduce xen_remap, use it instead of ioremap (Stefano Stabellini)   
- xen: close evtchn port if binding to irq fails (Wei Liu)   
- xen-evtchn: correct comment and error output (Wei Liu)   
- xen/tmem: Add missing %s in the printk statement. (Konrad Rzeszutek Wilk)   
- xen/acpi: move xen_acpi_get_pxm under CONFIG_XEN_DOM0 (Liu Jinsong)   
- xen/acpi: ACPI cpu hotplug (Liu Jinsong)   
- xen/acpi: Move xen_acpi_get_pxm to Xen's acpi.h (Liu Jinsong)   
- xen/stub: driver for CPU hotplug (Liu Jinsong)   
- xen/acpi: ACPI memory hotplug (Liu Jinsong)   
- xen/stub: driver for memory hotplug (Liu Jinsong)   
- xen: implement updated XENMEM_add_to_physmap_range ABI (Ian Campbell)   
- xen/smp: Move the common CPU init code a bit to prep for PVH patch. (Konrad Rzeszutek Wilk)   
- xen-blkfront: remove frame list from blk_shadow (Roger Pau Monne)   
- xen-blkfront: pre-allocate pages for requests (Roger Pau Monne)   
- xen-blkback: don't store dev_bus_addr (Roger Pau Monne)   
- xen-blkfront: switch from llist to list (Roger Pau Monne)   
- xen-blkback: fix foreach_grant_safe to handle empty lists (Roger Pau Monne)   
- xen-blkfront: replace kmalloc and then memcpy with kmemdup (Mihnea Dobrescu-Balaur)   
- xen-blkback: fix dispatch_rw_block_io() error path (Jan Beulich)   
- xen/blkback: Change statistics counter types to unsigned (Zoltan Kiss)   
- xen/blkback: correctly respond to unknown, non-native requests (David Vrabel)   
- xen/xen-blkback: preq.dev is used without initialized (Chen Gang)   
- xen-blkback: use balloon pages for persistent grants (Roger Pau Monne)   
- xen-blkfront: drop the use of llist_for_each_entry_safe (Konrad Rzeszutek Wilk) [Orabug: 16263164]  
- xen/blkback: Don't trust the handle from the frontend. (Konrad Rzeszutek Wilk)   
- xen-blkback: do not leak mode property (Jan Beulich)   

* Wed Jun 26 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-2.el6uek] 
- scsi_prep_fn() check for empty queue (Maxim Uvarov) [Orabug: 17015179]  
- CONFIG_SCSI_VIRTIO=m (Maxim Uvarov) [Orabug: 17002820]  
- kernel spec: comment out pesign requirement (Maxim Uvarov)   
- remove i686 build files (Maxim Uvarov)   
- ixgbevf driver update from 2.7.12-k to 2.8.7 (Maxim Uvarov)   
- ixgbe update from 3.11.33-k to 3.15.1 (Maxim Uvarov)   
- igbvf driver update from 2.0.2-k to 2.3.2 (Maxim Uvarov)   
- e1000e driver update from 2.1.4-k to 2.4.14-NAPI (Maxim Uvarov)   
- spec: change kernel version to uek3 (Maxim Uvarov)   
- igb driver update from 4.1.2-k to 4.3.0 (Maxim Uvarov)   
- support sparc64x chip type in cpumap (Allen Pais)   
- cpu hw caps support for sparc64x (Allen Pais)   
- correctly recognize SPARC64-X chips (Allen Pais)   
- OVPMAI: modified files to include ovmapi driver. (Cathy Avery) Merge OVMAPI
[Orabug: 16443145]  
- OVMAPI: Added uek2 driver to build. (Cathy Avery) Merge OVMAPI
[Orabug: 16443145]  

* Fri Jun 14 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-1.el6uek] 
- kconfig: turn on rcu_trace and rcu_torture_test (Maxim Uvarov) 
- sparc64 Kconfig and configs V1 (bob picco) 
- sparc64 irq_64 section mismatch fix (bob picco) 
- sparc64 sparse irq (bob picco) 
- sparc64 boot option open up /dev/mem again (bob picco) 
- sparc64 add mem to iomem resource (bob picco) 
- sparc64 strict_devmem (bob picco) 
- sparc64 find_node LDOM (bob picco) 
- sparc64 address-congruence property (bob picco) 
- sparc64 kconfig four level page table (bob picco) 
- sparc64 four level page table support (bob picco) 
- sparc64 move three level page table scheme (bob picco) 
- sparc64 expand linear mapping region (bob picco) 
- ioat3: add missing DMA unmap to ioat_xor_val_self_test() (Bartlomiej Zolnierkiewicz) [Orabug: 16495543] 
- perf/x86: Add Intel IvyBridge event scheduling constraints (Stephane Eranian) [Orabug: 16495525] 
- ksplice: Clear garbage data on the kernel stack when handling signals (Nelson Elhage) 
- spec: ol6 add multipath version deps (Maxim Uvarov) [Orabug: 16763586] 
- spec: fix suffix order of a directory name (Guangyu Sun) [Orabug: 16682371] 
- SPEC: add x86_energy_perf_policy tool Add tools/power/x86/x86_energy_perf_policy/x86_energy_perf_policy to ol5 ol6 uek kernel rpmbuild spec file and create shell wrapper for this tool. (ethan.zhao) [Orabug: 16036151] 
- spec: fix instalation if hardlink is installed (Maxim Uvarov) 
- SPEC: fix doc build (Guru Anbalagane) 
- spec: unique debuginfo (Maxim Uvarov) [Orabug: 16245366] 
- Enable CONFIG_SUNRPC_DEBUG by default. (Todd Vierling) [Orabug: 16879097] 
- x86: Add Xen kexec control code size check to linker script (Daniel Kiper) 
- drivers/xen: Export vmcoreinfo through sysfs (Daniel Kiper) 
- x86/xen/enlighten: Add init and crash kexec/kdump hooks (Daniel Kiper) 
- x86/xen: Add kexec/kdump makefile rules (Daniel Kiper) 
- x86/xen: Add x86_64 kexec/kdump implementation (Daniel Kiper) 
- x86/xen: Add i386 kexec/kdump implementation (Daniel Kiper) 
- x86/xen: Register resources required by kexec-tools (Daniel Kiper) 
- x86/xen: Introduce architecture dependent data for kexec/kdump (Daniel Kiper) 
- xen: Introduce architecture independent data for kexec/kdump (Daniel Kiper) 
- x86/kexec: Add extra pointers to transition page table PGD, PUD, PMD and PTE (Daniel Kiper) 
- kexec: introduce kexec_ops struct (Daniel Kiper) 
- spec: inc sublevel to 13 (Maxim Uvarov) 
- spec: add /boot/vmlinuz*.hmac needed for fips mode (John Haxby) [Orabug: 16807114] 
- spec: baselevel 12 (Maxim Uvarov) 
- Fix version.h include due to UAPI change in 3.7 (Dwight Engen) [Orabug: 16526862] 
- mtip32xx: set config option to enable build (Jerry Snitselaar) [Orabug: 16745449] 
- mpt3sas: set config options to enable build (Jerry Snitselaar) [Orabug: 16745449] 
- spec: baselevel 8 (Maxim Uvarov) 
- xen/mmu: On early bootup, flush the TLB when changing RO->RW bits Xen provided pagetables. (Konrad Rzeszutek Wilk) 
- Fix problem in Xen pvhugepages where page table walk to lock/unlock page table pages needed to be taught about hugepages. (Dave McCracken) 
- Add support for pv hugepages and support for huge balloon pages. (Dave McCracken) 
- update-el use 6.4 (Maxim Uvarov) 
- Spec: uek3/v3.8 initial build scripts (Maxim Uvarov) 
- scripts/sign-file fix typo (Maxim Uvarov) 
- kbuild: AFTER_LINK (Roland McGrath) 
- MODSIGN: Simplify Makefile with a Kconfig helper (Michal Marek) 
- MODSIGN: Add option to not sign modules during modules_install (Michal Marek) 
- MODSIGN: Specify the hash algorithm on sign-file command line (Michal Marek) 
- bnx2: Update driver to use new mips firmware. (Joe Jin) 
- ipmi: make kcs timeout parameters as module options (Pavel Bures) 
- perf: fix x86 compilation fix (Maxim Uvarov) 
- ocfs2: Add datavolume mount option (Guru Anbalagane) [Orabug: 16533805] 
- update-el use 6.4 (Maxim Uvarov) 
- Spec: uek3/v3.8 initial build scripts (Maxim Uvarov) 
- scripts/sign-file fix typo (Maxim Uvarov) 
- kbuild: AFTER_LINK (Roland McGrath) 
- MODSIGN: Simplify Makefile with a Kconfig helper (Michal Marek) 
- MODSIGN: Add option to not sign modules during modules_install (Michal Marek) 
- MODSIGN: Specify the hash algorithm on sign-file command line (Michal Marek) 
- bnx2: Update driver to use new mips firmware. (Joe Jin) 
- ipmi: make kcs timeout parameters as module options (Pavel Bures) 
- perf: fix x86 compilation fix (Maxim Uvarov) 
- Linux 3.8.13 (Greg Kroah-Hartman) This is the 3.8.13 stable release 

